@@ -3,6 +3,7 @@
 #include <config.h>
 
 #include "Viewer.h"
+#include "trx.h"
 #include "main.h"
 #include "viewpsk.h"
 #include "configuration.h"
@@ -11,12 +12,13 @@
 #include "fl_digi.h"
 #include "re.h"
 #include "gettext.h"
+#include "flmisc.h"
 #include "flinput2.h"
 #include "spot.h"
 
 #include <FL/Enumerations.H>
 #include <FL/Fl_Slider.H>
-#include <FL/fl_ask.H>
+#include <FL/Fl_Pack.H>
 
 #include <string>
 
@@ -46,7 +48,7 @@ int labelwidth[VIEWER_LABEL_NTYPES];
 int sbarwidth = 16;
 int border = 4;
 
-re_t seek_re("", REG_EXTENDED | REG_ICASE | REG_NOSUB);
+fre_t seek_re("", REG_EXTENDED | REG_ICASE | REG_NOSUB);
 int re_eflags = REG_NOTBOL | REG_NOTEOL;
 
 //unsigned int nchars = 80;
@@ -256,7 +258,7 @@ static void cb_Seek(Fl_Input *, void *)
 {
 	static Fl_Color seek_color[2] = { FL_FOREGROUND_COLOR,
 					  adjust_color(FL_RED, FL_BACKGROUND2_COLOR) }; // invalid RE
-	seek_re = *inpSeek->value() ? inpSeek->value() : "[invalid";
+	seek_re.recompile(*inpSeek->value() ? inpSeek->value() : "[invalid");
 	if (inpSeek->textcolor() != seek_color[!seek_re]) {
 		inpSeek->textcolor(seek_color[!seek_re]);
 		inpSeek->redraw();
@@ -280,7 +282,7 @@ Fl_Double_Window* createViewer() {
 	static int viewerwidth = (progStatus.VIEWERnchars * cwidth) + cols[0] + sbarwidth + border;
 	static int viewerheight = 50 + cheight * progdefaults.VIEWERchannels + border;
 
-	w = new Fl_Double_Window(progStatus.VIEWERxpos, progStatus.VIEWERypos, viewerwidth, viewerheight, _("Psk Viewer"));
+	w = new Fl_Double_Window(progStatus.VIEWERxpos, progStatus.VIEWERypos, viewerwidth, viewerheight, _("PSK Browser"));
 	w->xclass(PACKAGE_NAME);
 	p = new Fl_Pack(0,0,viewerwidth, viewerheight);
 		Fl_Pack *p1 = new Fl_Pack(0, 0, viewerwidth, 25);
