@@ -355,7 +355,7 @@ void Cmovavg::reset()
 // subtracted. These end-effects are easy to perform if we treat the new sample
 // as occurring at time t = 0, because the transform of a single sample at t = 0,
 // say (a + bj), simply has all frequency bins equal to (a + bj). Similarly, the
-// oldest sample that has just isappeared off the end of the window is exactly N
+// oldest sample that has just disappeared off the end of the window is exactly N
 // samples old. I.e. it occurred at t = -N. The transform of this sample, 
 // say (c + dj), is also straightforward since every frequency bin has now been
 // phase-rotated an integer number of times from when the sample was at t = 0. 
@@ -396,12 +396,10 @@ void Cmovavg::reset()
 // require the store of the history associated with those bins over the 
 // kernel length.
 //
-// Use in the MFSK modem for extraction of the frequency spectra
+// Use in the MFSK / DOMINO modem for extraction of the frequency spectra
 //
 //=====================================================================
 
-// K1 is defined in filters.h to be 0.9999
-
 sfft::sfft(int len, int _first, int _last)
 {
 	vrot = new complex[len];
@@ -412,15 +410,14 @@ sfft::sfft(int len, int _first, int _last)
 	last = _last;
 	ptr = 0;
 	double phi = 0.0, tau = 2.0 * M_PI/ len;
+	k2 = 1.0;
 	for (int i = 0; i < len; i++) {
 		vrot[i].re = K1 * cos (phi);
 		vrot[i].im = K1 * sin (phi);
 		phi += tau;
 		delay[i] = bins[i] = 0.0;
+		k2 *= K1;
 	}
-	k2 = pow(K1, len); 
-// could also compute k2 *= K1 in the loop,
-// initializing k2 = K1;
 }
 
 sfft::~sfft()
@@ -435,14 +432,16 @@ sfft::~sfft()
 // Values are not stable until more than "len" samples have been processed.
 // returns address of first component in array
 
-complex *sfft::run(complex input)
+complex *sfft::run(const complex& input)
 {
-	complex z;// = input - delay[ptr] * k2;
+	complex z;
 	complex y;
-	z.re = - k2 * delay[ptr].re + input.re;
-	z.im = - k2 * delay[ptr].im + input.im;
-	delay[ptr++] = input;
-	ptr %= fftlen;
+
+	z.re = input.re - k2 * delay[ptr].re;
+	z.im = input.im - k2 * delay[ptr].im;
+	delay[ptr] = input;
+
+	ptr = (ptr + 1) % fftlen;
 	
 	for (int i = first; i < last; i++) {
 		y = bins[i] + z;
@@ -450,3 +449,84 @@ complex *sfft::run(complex input)
 	}
 	return &bins[first];
 }
+
+// ============================================================================
+// Goertzel filter
+// Optimized implementation of a DFT for a single frequency of interest
+// SR = sample rate
+// N = Block size (does not need to be a factor of 2!)
+//     bin size = SR / N
+// K = frequency bin of interest = (N * freq / SR)
+//     N should be selected to make K an integer if possible
+//
+// Q0 = current sample
+// Q1 = previous sample (1 delay)
+// Q2 = previous sample (2 delay)
+// w  = (2 * pi * K / N)
+// k1 = cos(w)
+// k2 = sin(w)
+// k3 = 2.0 * k1
+
+// Q0, Q1, Q2 are initialized to zero
+// Iterate N times:
+// Q0 = k3*Q1 - Q2 + sample
+// Q2 = Q1
+// Q1 = Q0
+//
+// After N interations:
+// real = (Q1 - Q2 * k1)
+// imag = Q2 * k2
+// or
+// mag = Q1*Q1 + Q2*Q2 - Q1*Q2*k1
+// ============================================================================
+
+goertzel::goertzel(double sr, int n, int k)
+{
+	double w;
+	SR = sr;
+	K = k;
+	N = n;
+	w = 4.0 * M_PI * K / N;
+	k1 = cos(w);
+	k2 = sin(w);
+	k3 = 2.0 * k1;
+	Q0 = Q1 = Q2 = 0.0;
+	count = N;
+}
+
+goertzel::~goertzel()
+{
+}
+
+void goertzel::reset()
+{
+	Q0 = Q1 = Q2 = 0.0;
+	count = N;
+}
+
+bool goertzel::run(double sample)
+{
+	Q0 = k1 * Q1 - Q2 + sample;
+	Q2 = Q1;
+	Q1 = Q0;
+	if (--count == 0) {
+		count = N;
+		return true;
+	}
+	return false;
+}
+
+double goertzel::real()
+{
+	return (Q1 - Q2 * k1);
+}
+
+double goertzel::imag()
+{
+	return (Q2 * k2);
+}
+
+double goertzel::mag()
+{
+	return (Q1*Q1 - Q2*Q2 - Q1*Q2*k1);
+}
