@@ -35,10 +35,6 @@
 #ifndef _FREQCONTROL_H_
 #define _FREQCONTROL_H_
 
-#include <math.h>
-#include <stdio.h>
-#include <string.h>
-
 #include <FL/Fl.H>
 #include <FL/Fl_Widget.H>
 #include <FL/Fl_Repeat_Button.H>
@@ -91,6 +87,7 @@ private:
 	void IncFreq(int n);
 	int (*cbFunc)();
 	static void freq_input_cb(Fl_Widget* input, void* arg);
+	void cancel_kb_entry(void);
 protected:
 	long val, oldval;
 };
