@@ -1,13 +1,11 @@
 #ifndef ADIFIO
 #define ADIFIO
 
-#include <stdio.h>
-#include <string.h>
-#include <stdlib.h>
+#include <cstdio>
 
 #include "qso_db.h"
 
-#define ADIF_VERS "2.1.9"
+#define ADIF_VERS "2.2.3"
 
 class cAdifIO {
 private:
