@@ -3,8 +3,8 @@
 
 #include <string>
 
-#include "main.h"
 #include "rtty.h"
+#include "waterfall.h"
 #include "lookupcall.h"
 #include "Viewer.h"
 
@@ -16,7 +16,7 @@
 #  define DEFAULT_PTTDEV "/dev/ttyd0"
 #  define DEFAULT_CWFSKPORT "/dev/ttyd1"
 #  define DEFAULT_HAMRIGDEVICE "/dev/ttyd0"
-#elif defined(__CYGWIN__)
+#elif defined(__WOE32__)
 #  define DEFAULT_PTTDEV "COM1"
 #  define DEFAULT_CWFSKPORT "COM2"
 #  define DEFAULT_HAMRIGDEVICE "COM1"
@@ -40,6 +40,9 @@
         ELEM_(bool, rsidWideSearch, "RSIDWIDESEARCH", false)                            \
         ELEM_(bool, rsid, "", false)                                                    \
         ELEM_(bool, TransmitRSid, "TRANSMITRSID", false)                                \
+        ELEM_(bool, rsid_mark, "RSIDMARK", true)                                        \
+        ELEM_(bool, rsid_notify_only, "RSIDNOTIFYONLY", false)                          \
+                                                                                        \
         ELEM_(bool, slowcpu, "SLOWCPU", true)                                           \
                                                                                         \
         ELEM_(bool, changed, "", false)                                                 \
@@ -64,7 +67,10 @@
         ELEM_(bool, StatusDim, "STATUSDIM", true)                                       \
         ELEM_(double, StatusTimeout, "STATUSTIMEOUT", 15.0)                             \
         ELEM_(bool, PSKmailSweetSpot, "PSKMAILSWEETSPOT", false)                        \
-        ELEM_(int, ServerOffset, "PSKSERVEROFFSET", 40)                                 \
+        ELEM_(int, ServerOffset, "PSKSERVEROFFSET", 50)                                 \
+        ELEM_(int, ServerCarrier, "PSKSERVERCARRIER", 1500)                             \
+        ELEM_(int, ServerAFCrange, "PSKSERVERAFCRANGE", 25)                             \
+        ELEM_(double, ServerACQsn, "PSKSERVERACGSN", 6.0)                               \
 /* RTTY */                                                                              \
         ELEM_(int, rtty_shift, "RTTYSHIFT", 3) /* 170 */                                \
         ELEM_(int, rtty_baud, "RTTYBAUD", 0)   /* 45 */                                 \
@@ -92,6 +98,8 @@
         ELEM_(bool, useCWkeylineDTR, "", false)                                         \
         ELEM_(int, CWweight, "CWWEIGHT", 50)                                            \
         ELEM_(int, CWspeed, "CWSPEED", 18)                                              \
+        ELEM_(int, CWfarnsworth, "CWFARNSWORTH", 18)                                    \
+        ELEM_(bool, CWusefarnsworth, "CWUSEFARNSWORTH", false)                          \
         ELEM_(int, defCWspeed, "CWDEFSPEED", 24)                                        \
         ELEM_(int, CWbandwidth, "CWBANDWIDTH", 150)                                     \
         ELEM_(bool, CWtrack, "CWTRACK", true)                                           \
@@ -110,7 +118,14 @@
         ELEM_(int, QSKshape, "QSKSHAPE", 0)                                             \
         ELEM_(bool, CWnarrow, "CWNARROW", false)                                        \
 /* FELD HELL */                                                                         \
-        ELEM_(double, HELL_BW, "", 150.0)                                               \
+        ELEM_(double, HELL_BW, "HELL_BW0", 245.0)                                       \
+        ELEM_(double, HELL_BW_FH, "HELL_BW1", 245.0)                                    \
+        ELEM_(double, HELL_BW_SH, "HELL_BW2", 30.0)                                     \
+        ELEM_(double, HELL_BW_X5, "HELL_BW3", 1225.)                                    \
+        ELEM_(double, HELL_BW_X9, "HELL_BW4", 2205.0)                                   \
+        ELEM_(double, HELL_BW_FSK, "HELL_BW5", 180.0)                                   \
+        ELEM_(double, HELL_BW_FSK105, "HELL_BW6", 100.0)                                \
+        ELEM_(double, HELL_BW_HELL80, "HELL_BW7", 450.0)                                \
         ELEM_(bool, HellRcvWidth, "HELLRCVWIDTH", false)                                \
         ELEM_(bool, HellBlackboard, "HELLBLACKBOARD", false)                            \
         ELEM_(int, HellXmtWidth, "HELLXMTWIDTH", 1)                                     \
@@ -138,6 +153,10 @@
 /* MT63 */                                                                              \
         ELEM_(bool, mt63_8bit, "MT638BIT", false)                                       \
         ELEM_(int, mt63_interleave, "MT63INTERLEAVE", 64) /* long interleave */         \
+        ELEM_(bool, mt63_rx_integration, "MT63INTEGRATION", false)                      \
+        ELEM_(bool, mt63_twotones, "MT63TWOTONES", true)                                \
+        ELEM_(bool, mt63_usetones, "MT63USETONES", true)                                \
+        ELEM_(int, mt63_tone_duration, "MT63TONEDURATION", 4)                           \
 /* Waterfall & UI */                                                                    \
         ELEM_(uchar, red, "", 0)                                                        \
         ELEM_(uchar, green, "", 255)                                                    \
@@ -178,7 +197,7 @@
         ELEM_(bool, autoextract, "AUTOEXTRACT", false)                                  \
         ELEM_(bool, speak, "SPEAK", false)                                              \
 /* QRZ */                                                                               \
-        ELEM_(int, QRZ, "QRZTYPE", 0) /* Not available */                               \
+        ELEM_(int, QRZ, "QRZTYPE", QRZNONE)                                             \
         ELEM_(std::string, QRZpathname, "QRZPATHNAME", "")                              \
         ELEM_(std::string, QRZusername, "QRZUSER", "")                                  \
         ELEM_(std::string, QRZuserpassword, "QRZPASSWORD", "")                          \
@@ -227,7 +246,7 @@
         ELEM_(bool, HamlibXONXOFFflow, "HAMLIBXONXOFFFLOW", 0)                          \
         ELEM_(int, HamlibRetries, "HAMLIBRETRIES", 2)                                   \
         ELEM_(int, HamlibTimeout, "HAMLIBTIMEOUT", 10)                                  \
-        ELEM_(int, HamlibWait, "HAMLIBWAIT", 50)                                        \
+        ELEM_(int, HamlibWait, "HAMLIBWAIT", 5)                                         \
         ELEM_(int, HamlibWriteDelay, "HAMLIBWRITEDELAY", 0)                             \
         ELEM_(int, HamlibSideband, "HAMLIBSIDEBAND", 0) /* SIDEBAND_RIG */              \
 /* Operator */                                                                          \
@@ -270,10 +289,7 @@
         ELEM_(int, ContestDigits, "CONTESTDIGITS", 4)                                   \
         ELEM_(std::string, myXchg, "MYXCGH", "")                                        \
         ELEM_(std::string, mytxpower, "TXPOWER", "")                                    \
-/* Macro timer constants and controls */                                                \
-        ELEM_(bool, useTimer, "USETIMER", false)                                        \
-        ELEM_(int, macronumber, "MACRONUMBER", 0)                                       \
-        ELEM_(int, timeout, "TIMEOUT", 0)                                               \
+/* Macro controls */                                                                    \
         ELEM_(bool, UseLastMacro, "USELASTMACRO", false)                                \
         ELEM_(bool, DisplayMacroFilename, "DISPLAYMACROFILENAME", false)                \
 /* Mixer */                                                                             \
