@@ -22,27 +22,17 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 // ----------------------------------------------------------------------------
 
-#ifndef fl_digi_h
+#ifndef FL_DIGI_H
+#define FL_DIGI_H
 
-#define fl_digi_h
-
-#include <string.h>
-
-#include <FL/Fl.H>
 #include <FL/Fl_Double_Window.H>
-#include <FL/Fl_Menu_Bar.H>
-#include <FL/Fl_Pack.H>
-#include <FL/Fl_Text_Buffer.H>
 #include <FL/Fl_Browser.H>
 #include <FL/Fl_Value_Slider.H>
 #include <FL/Fl_Input.H>
-#include <FL/Fl_Tile.H>
-#include <FL/Fl_Light_Button.H>
-#include <FL/Fl_Check_Button.H>
-#include <FL/Fl_Menu_Item.H>
 
 #include "combo.h"
-#include "FTextView.h"
+#include "Fl_Tile_Check.h"
+#include "FTextRXTX.h"
 #include "raster.h"
 #include "waterfall.h"
 #include "digiscope.h"
@@ -50,18 +40,17 @@
 #include "mixer.h"
 #include "progress.h"
 #include "FreqControl.h"
-#include <flinput2.h>
+#include "flinput2.h"
 
-using namespace std;
 
 extern Fl_Double_Window *fl_digi_main;
 extern Fl_Double_Window *scopeview;
 //extern Fl_Double_Window *opBrowserView;
 
-extern FTextView		*ReceiveText;
-extern FTextEdit		*TransmitText;
+extern FTextRX			*ReceiveText;
+extern FTextTX			*TransmitText;
 extern Raster			*FHdisp;
-extern Fl_Tile_check	*TiledGroup;
+extern Fl_Tile_Check		*TiledGroup;
 extern Fl_Box			*StatusBar;
 extern Fl_Box			*Status2;
 extern Fl_Box			*Status1;
@@ -108,12 +97,13 @@ extern Fl_Button		*qso_btnClearList;
 
 extern Fl_Value_Slider		*valRcvMixer;
 extern Fl_Value_Slider		*valXmtMixer;
-extern Fl_Button		*btn_afconoff;
-extern Fl_Button		*btn_sqlonoff;
+extern Fl_Button		*btnAFC;
+extern Fl_Button		*btnSQL;
+extern Fl_Light_Button  *btnRSID;
+extern Fl_Light_Button  *btnTune;
+
 extern Fl_Button		*btnAltMacros;
 extern Fl_Button		*btnMacroTimer;
-extern Fl_Button		*btnMacroDummy;
-
 
 extern bool				useCheckButtons;
 extern int				altMacros;
@@ -161,8 +151,8 @@ extern void put_Status1(const char *msg, double timeout = 0.0, status_timeout ac
 extern void put_Status2(const char *msg, double timeout = 0.0, status_timeout action = STATUS_CLEAR);
 
 extern void show_frequency(long long);
-extern void show_mode(const string& mode);
-extern void show_bw(const string& sWidth);
+extern void show_mode(const std::string& mode);
+extern void show_bw(const std::string& sWidth);
 extern void show_spot(bool v);
 extern void showMacroSet();
 
@@ -200,6 +190,7 @@ extern void colorize_macros();
 extern void set_rtty_tab_widgets();
 extern void set_olivia_tab_widgets();
 
+extern void startMacroTimer();
 extern void stopMacroTimer();
 extern void cb_ResetSerNbr();
 extern void updateOutSerNo();
@@ -207,13 +198,11 @@ extern void updateOutSerNo();
 const char* zdate(void);
 const char* ztime(void);
 
-Fl_Color adjust_color(Fl_Color fg, Fl_Color bg);
-
 extern void setTabColors();
 
 void qsy(long long rfc, long long fmid = -1LL);
 
-unsigned quick_choice_menu(const char* title, unsigned sel, const Fl_Menu_Item* menu);
-unsigned quick_choice(const char* title, unsigned sel, ...);
+void note_qrg(bool no_dup = true, const char* prefix = " ", const char* suffix = " ",
+	      trx_mode mode = NUM_MODES, long long rfc = 0LL, int afreq = 0);
 
 #endif
