@@ -28,7 +28,6 @@
 
 #include <stdint.h>
 #include <string>
-#include "fldigi-config.h"
 
 enum state_t {
 	STATE_PAUSE = 0,
@@ -167,12 +166,17 @@ std::istream& operator>>(std::istream& s, qrg_mode_t& m);
 
 
 enum band_t {
-	BAND_LMW, BAND_160M, BAND_80M, BAND_75M, BAND_60M, BAND_40M, BAND_30M, BAND_20M,
+	BAND_160M, BAND_80M, BAND_75M, BAND_60M, BAND_40M, BAND_30M, BAND_20M,
 	BAND_17M, BAND_15M, BAND_12M, BAND_10M, BAND_6M, BAND_4M, BAND_2M, BAND_125CM,
-	BAND_70CM, BAND_33CM, BAND_23CM, BAND_13CM, BAND_9CM, BAND_OTHER, NUM_BANDS
+	BAND_70CM, BAND_33CM, BAND_23CM, BAND_13CM, BAND_9CM, BAND_6CM, BAND_3CM, BAND_125MM,
+	BAND_6MM, BAND_4MM, BAND_2P5MM, BAND_2MM, BAND_1MM, BAND_OTHER, NUM_BANDS
 };
 
 band_t band(long long freq_hz);
+band_t band(const char* freq_mhz);
 const char* band_name(band_t b);
+const char* band_name(const char* freq_mhz);
+const char* band_freq(band_t b);
+const char* band_freq(const char* band_name);
 
 #endif
