@@ -1,23 +1,20 @@
 #ifndef _LOG_H
 #define _LOG_H
 
-#include <fstream>
+#include <cstdio>
 #include <string>
 
 class cLogfile {
 public:
-	enum log_t {
-		LOG_RX = 0,
-		LOG_TX = 1
-	};
+	enum log_t { LOG_RX, LOG_TX, LOG_START, LOG_STOP };
 private:
-	std::ofstream	_logfile;
+	FILE*	logfile;
 	bool	retflag;
 	log_t	logtype;
-	std::string	logfilename;
 
 public:
-	cLogfile(const std::string& fname = "fldigi.log");
+	cLogfile(const std::string& fname);
+	~cLogfile();
 	void	log_to_file(log_t type, const std::string& s);
 	void	log_to_file_start();
 	void	log_to_file_stop();
