@@ -25,7 +25,7 @@
 #ifndef _MISC_H
 #define _MISC_H
 
-#include <math.h>
+#include <cmath>
 
 extern unsigned long hweight32(unsigned long w);
 extern unsigned short int hweight16(unsigned short int w);
@@ -35,9 +35,7 @@ extern unsigned long rbits32(unsigned long w);
 extern unsigned short int rbits16(unsigned short int w);
 extern unsigned char rbits8(unsigned char w);
 
-#ifndef __CYGWIN__
-extern unsigned int log2(unsigned int x);
-#endif
+extern unsigned int log2u(unsigned int x);
 
 extern unsigned char graydecode(unsigned char data);
 extern unsigned char grayencode(unsigned char data);
@@ -97,4 +95,6 @@ void BlackmanWindow(double *array, int n);
 // Simple about effective as Hamming or Hanning
 void TriangularWindow(double *array, int n);
 
+#define fftabs(a,b) sqrt((a)*(a) + (b)*(b))
+
 #endif
