@@ -26,18 +26,9 @@
 #ifndef picture_H
 #define picture_H
 
-#include <math.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
-
-#include <FL/Fl.H>
-#include <FL/Fl_Double_Window.H>
 #include <FL/Fl_Widget.H>
-#include <FL/fl_draw.H>
 #include <FL/Fl_Box.H>
-
-#include "threads.h"
+#include <FL/Fl_Image.H>
 
 class picture : public Fl_Widget { 
 private:
@@ -46,7 +37,6 @@ private:
 	int width;
 	int height;
 	int depth;
-	int quality;
 	int numcol;
 	int slantdir;
 	void slant_corr(int x, int y);
@@ -63,12 +53,7 @@ public:
 	void	clear();
 	void	image(Fl_Image *img) {Fl_Widget::image(img);}
 	void	resize(int, int, int, int);
-#if USE_LIBJPEG
-	int	save_jpeg(const char *);
-#endif
-#if USE_LIBPNG
 	int	save_png(const char *);
-#endif
 };
 
 class picbox : public Fl_Box
