@@ -47,15 +47,25 @@
 #  define HAVE_UHROUTER 0
 #endif
 
+#if HAVE_TERMIOS_H
+#  define HAVE_TTYPORT 1
+#else
+#  define HAVE_TTYPORT 0
+#endif
+
 struct termios;
 
+#ifdef __MINGW32__
+#  include "serial.h"
+#endif
+
 class PTT {
 public:
 	// The ptt_t enums must be defined even if the corresponding
 	// code is not compiled.  New tags go to the end of the list.
 	enum ptt_t {
 		PTT_INVALID = -1, PTT_NONE, PTT_HAMLIB, PTT_MEMMAP,
-		PTT_RIGCAT, PTT_TTY, PTT_PARPORT, PTT_UHROUTER,
+		PTT_RIGCAT, PTT_TTY, PTT_PARPORT, PTT_UHROUTER
 	};
 
 	PTT(ptt_t dev = PTT_NONE);
@@ -75,6 +85,10 @@ private:
 	int uhfd[2];  // ptt
 #endif
 
+#ifdef __MINGW32__
+	Cserial serPort;
+#endif
+
 	void close_all(void);
 
 	void open_tty(void);
