@@ -23,7 +23,11 @@
 #ifndef RE_H_
 #define RE_H_
 
-#include <regex.h>
+#if HAVE_REGEX_H
+#  include <regex.h>
+#else
+#  include "compat/regex.h"
+#endif
 #include <string>
 #include <vector>
 
@@ -34,13 +38,20 @@ public:
 	re_t(const re_t& re);
 	~re_t();
 	re_t& operator=(const re_t& rhs);
-	re_t& operator=(const char* pattern_);
-	operator bool(void) { return !error; }
+	void recompile(const char* pattern_);
+	operator bool(void) const { return !error; }
+	bool operator==(const re_t& o) const { return o.cflags == cflags && o.pattern == pattern; }
 
 	bool match(const char* str, int eflags_ = 0);
-	const std::string& submatch(size_t n);
-	void suboff(size_t n, int* start, int* end);
-	size_t nsub(void) { return substrings.size(); }
+	const std::string& submatch(size_t n) const;
+	void suboff(size_t n, int* start, int* end) const;
+	const std::vector<regmatch_t>& suboff(void) const { return suboffsets; }
+
+	size_t nsub(void) const { return suboffsets.size(); }
+	const std::string& re(void) const { return pattern; }
+	int cf(void) const { return cflags; }
+
+	size_t hash(void) const;
 protected:
 	void compile(void);
 
@@ -50,28 +61,19 @@ protected:
 	std::vector<regmatch_t> suboffsets;
 	std::vector<std::string> substrings;
 	bool error;
+	bool need_substr;
 };
 
-class fre_t : private re_t
+class fre_t : public re_t
 {
 public:
 	fre_t(const char* pattern_, int cflags_ = 0);
-	operator bool(void) { return !error; }
-
 	bool match(const char* str, int eflags_ = 0);
-	const std::vector<regmatch_t>& suboff(void) { return suboffsets; }
-
-private:
-	fre_t(const fre_t& re);
-	fre_t& operator=(const fre_t& rhs);
 };
 
-#include <sys/types.h>
-#if (defined(__GLIBC__) && __GLIBC__ >= 2 && __GLIBC_MINOR__ >= 3) || \
-	defined(__FreeBSD__) || defined(__APPLE__)
-#  define HAVE_REGEX_BACKREF 1
-#else
-#  define HAVE_REGEX_BACKREF 0
-#endif
-
 #endif // RE_H_
+
+// Local Variables:
+// mode: c++
+// c-file-style: "linux"
+// End:
