@@ -4,21 +4,14 @@
 #include <FL/Fl_Double_Window.H>
 
 #include <string>
-#include <list>
-#include <sstream>
-#include <iostream>
-#include <ctype.h>
 
 #include "serial.h"
-
 #if USE_HAMLIB
 	#include "hamlib.h"
 #endif
 
-using namespace std;
-
 extern Fl_Double_Window *rigcontrol;
-extern string windowTitle;
+extern std::string windowTitle;
 extern Cserial rigio;
 
 extern void initOptionMenus();
@@ -35,6 +28,7 @@ extern int  qso_movFreq();
 extern int	cb_qso_opMODE();
 extern int  cb_qso_opBW();
 extern void qso_setMode();
+extern void setTitle();
 
 extern void selectFreq();
 extern void delFreq();
@@ -55,7 +49,7 @@ extern bool init_rigMEM_RigDialog();
 #if USE_HAMLIB
 extern bool init_Hamlib_RigDialog();
 extern void selMode(rmode_t m);
-extern string modeString(rmode_t m);
+extern std::string modeString(rmode_t m);
 #endif
 
 extern Fl_Double_Window * createRigDialog();
