@@ -25,10 +25,14 @@
 
 #include <config.h>
 
-#include <sys/socket.h>
-#include <netdb.h>
-#include <netinet/in.h>
 #include <sys/time.h>
+#ifndef __MINGW32__
+#  include <sys/socket.h>
+#  include <netdb.h>
+#  include <netinet/in.h>
+#else
+#  include <winsock2.h>
+#endif
 
 #include <string>
 #include <exception>
@@ -135,6 +139,8 @@ public:
 	size_t recv(std::string& buf);
 
 	// Options
+	int get_bufsize(int dir);
+	void set_bufsize(int dir, int len);
 	void set_nonblocking(bool v = true);
 	void set_nodelay(bool v = true);
 	void set_timeout(const struct timeval& t);
