@@ -27,12 +27,8 @@
 
 #include "threads.h"
 #include "modem.h"
-
-#include "misc.h"
 #include "sound.h"
-#include "waterfall.h"
 #include "globals.h"
-#include "fl_digi.h"
 #include "rsid.h"
 
 // ----------------------------------------------------------------------------
@@ -48,9 +44,7 @@ extern	void	trx_receive();
 extern	void	trx_reset(void);
 extern	void	trx_start_macro_timer();
 
-extern void	wait_trx_state_prep(void);
-extern void	wait_trx_state_wait(void);
-extern void	wait_trx_state_cmpl(void);
+extern void	trx_wait_state(void);
 
 extern	void	macro_timer(void *);
 
@@ -65,11 +59,9 @@ extern  bool bHistory;
 #define TRX_WAIT(s_, code_)			\
 	do {					\
 		ENSURE_NOT_THREAD(TRX_TID);	\
-		wait_trx_state_prep();		\
 		code_;				\
 		while (trx_state != s_)		\
-			wait_trx_state_wait();	\
-		wait_trx_state_cmpl();		\
+			trx_wait_state();	\
 	} while (0)
 
 #endif
