@@ -1,6 +1,8 @@
 #ifndef XMLRPC_H
 #define XMLRPC_H
 
+#include <iosfwd>
+
 class Socket;
 
 class XML_RPC_Server
@@ -8,12 +10,13 @@ class XML_RPC_Server
 public:
 	static void start(const char* node, const char* service);
 	static void stop(void);
+	static std::ostream& list_methods(std::ostream& out);
 private:
 	XML_RPC_Server();
 	~XML_RPC_Server();
 	XML_RPC_Server(const XML_RPC_Server&);
 	XML_RPC_Server operator=(const XML_RPC_Server&);
-	void add_methods(void);
+	static void add_methods(void);
 	static void* thread_func(void*);
 
 private:
@@ -22,4 +25,6 @@ private:
 	Socket* server_socket;
 };
 
+void xmlrpc_set_qsy(long long rfc, long long fmid);
+
 #endif // XMLRPC_H
