@@ -3,16 +3,19 @@
 #include <FL/fl_ask.H>
 
 #include <string>
-#include <iostream>
-#include <ctime>
+#include <cstring>
+#include <cstdlib>
+#include <string>
 
 #include "adif_io.h"
 #include "config.h"
 #include "lgbook.h"
+#include "icons.h"
+#include "gettext.h"
 
 using namespace std;
 
-#ifdef __CYGWIN__
+#ifdef __WOE32__
 static const char *szEOL = "\r\n";
 #else
 static const char *szEOL = "\n";
@@ -40,7 +43,7 @@ FIELD fields[] = {
     {IOTA, 			"IOTA",       	0,  6, &btnSelectIOTA},        // Islands on the air 
     {ITUZ,			"ITUZ",       	0,  6, &btnSelectITUZ},        // ITU zone
     {MODE,			"MODE",         0,  8, &btnSelectMode},        // QSO mode
-	{MYXCHG,		"MYXCHG",       0, 20, &btnSelectMyXchg},      // contest exchange sent
+	{MYXCHG,		"STX_STRING",   0, 40, &btnSelectMyXchg},      // contest exchange sent
     {NAME, 			"NAME",         0, 18, &btnSelectName},        // contacted operators NAME
     {NOTES, 		"NOTES",        0, 80, &btnSelectNotes},       // QSO notes
     {OPERATOR,		"OPERATOR",   	0, 10, NULL},                  // Callsign of person logging the QSO
@@ -67,7 +70,7 @@ FIELD fields[] = {
     {TIME_ON, 		"TIME_ON",      0,  4, &btnSelectTimeON},      // HHMM or HHMMSS in UTC
     {TX_PWR, 		"TX_PWR",       0,  4, &btnSelectTX_pwr},      // power transmitted by this station
     {VE_PROV,		"VE_PROV",      0,  2, &btnSelectProvince},    // 2 letter abbreviation for Canadian Province
-	{XCHG1,			"XCHG1",        0, 20, &btnSelectXchgIn}       // contest exchange #1 / free1 in xlog
+	{XCHG1,			"SRX_STRING",   0, 40, &btnSelectXchgIn}       // contest exchange #1 / free1 in xlog
 };
 
 int numfields = sizeof(fields) / sizeof(FIELD);
@@ -89,26 +92,27 @@ int fieldnbr (const char *s) {
 
 int findfield( char *p )
 {
-	int low = 0;
-	int high = numfields - 1;
-	int middle;
+	int m;
 	int test;
 	
     if (strncasecmp (p, "EOR>", 4) == 0)
         return -1;
-    
-	while( low <= high ) {
-		middle = ( low  + high ) / 2;
-		if ( (test = strncasecmp( p, 
-                                  fields[middle].name, 
-                                  fields[middle].len ) ) == 0 ) { //match
-            if (fields[middle].type == COMMENT) return(NOTES);
-            return fields[middle].type;
-        }
-		else if( test < 0 )
-			high = middle - 1;		//search low end of array
-		else
-			low = middle + 1;		//search high end of array
+
+// following two tests are for backward compatibility with older
+// fldigi fields
+// changed to comply with ADIF 2.2.3
+
+	if (strncasecmp (p, "XCHG1>", 6) == 0)
+		return XCHG1;
+	if (strncasecmp (p, "MYXCHG>", 7) == 0)
+		return MYXCHG;
+
+    string tststr;
+    for (m = 0; m < numfields; m++) {
+        tststr = fields[m].name;
+        tststr += ':';
+        if ( (test = strncasecmp( p, tststr.c_str(), tststr.length() )) == 0)
+            return fields[m].type;
 	}
 	return -2;		//search key not found
 }
@@ -160,18 +164,18 @@ void cAdifIO::readFile (const char *fname, cQsoDb *db) {
     
 // relaxed file integrity test to all importing from non conforming log programs
     if (filesize == 0) {
-    	fl_message("Empty ADIF logbook file");
+	fl_alert2(_("Empty ADIF logbook file"));
+	return;
+    }
+    if ((strcasestr(buff, "<ADIF_VER:") != 0) &&
+	(strcasestr(buff, "<CALL:") == 0)) {
+	fl_alert2(_("No records in ADIF logbook file"));
     	return;
-	}
-	if ((strcasestr(buff, "<ADIF_VER:") != 0) &&
-	    (strcasestr(buff, "<CALL:") == 0)) {
-    	fl_message("No records in ADIF logbook file");
+    }
+    if (strcasestr(buff, "<CALL:") == 0) {
+	fl_alert2(_("Not an ADIF file"));
     	return;
-	}
-	if (strcasestr(buff, "<CALL:") == 0) {
-    	fl_message("Not an ADIF file");
-    	return;
-	}
+    }
 
 	char *p1 = buff, *p2;
 // is there a header?
