@@ -1,14 +1,15 @@
 #include <config.h>
 
-#include <stdlib.h>
 #include <string>
+#include <cstring>
+#include <cstdlib>
 
 #include "main.h"
-#include "modem.h"
+#include "trx.h"
 #include "debug.h"
 #include "macros.h"
 #include "status.h"
-#include "spot.h"
+#include "date.h"
 
 #include "adif_io.h"
 
@@ -22,7 +23,10 @@
 #include "configuration.h"
 #include "main.h"
 #include "locator.h"
+#include "icons.h"
+#include "gettext.h"
 
+#include <FL/filename.H>
 #include <FL/fl_ask.H>
 
 using namespace std;
@@ -40,7 +44,7 @@ void Export_CSV()
 	cQsoRec *rec;
 
 	string filters = "CSV\t*." "csv";
-	const char* p = FSEL::saveas("Export to CSV file", filters.c_str(),
+	const char* p = FSEL::saveas(_("Export to CSV file"), filters.c_str(),
 					 "export." "csv");
 	if (!p)
 		return;
@@ -62,7 +66,7 @@ void Export_TXT()
 	cQsoRec *rec;
 
 	string filters = "TEXT\t*." "txt";
-	const char* p = FSEL::saveas("Export to fixed field text file", filters.c_str(),
+	const char* p = FSEL::saveas(_("Export to fixed field text file"), filters.c_str(),
 					 "export." "txt");
 	if (!p)
 		return;
@@ -100,7 +104,7 @@ void Export_ADIF()
 	adifFile.writeFile (p, &qsodb);
 }
 
-savetype export_to = ADIF;
+static savetype export_to = ADIF;
 
 void Export_log()
 {
@@ -113,13 +117,18 @@ void saveLogbook()
 {
 	if (!qsodb.isdirty()) return;
 	if (progdefaults.NagMe)
-		if (!fl_choice("Save changed Logbook?", "No", "Yes", NULL)) 
+		if (!fl_choice2(_("Save changed Logbook?"), _("No"), _("Yes"), NULL)) 
 			return;
 	if (adifFile.writeLog (logbook_filename.c_str(), &qsodb))
-		fl_message ("Could not update file %s", logbook_filename.c_str());
+		fl_alert2(_("Could not update file %s"), logbook_filename.c_str());
 	qsodb.isdirty(0);
 }
 
+static void dxcc_entity_cache_clear(void);
+static void dxcc_entity_cache_add(cQsoRec* r);
+static void dxcc_entity_cache_rm(cQsoRec* r);
+static void dxcc_entity_cache_add(cQsoDb& db);
+
 void cb_mnuNewLogbook(Fl_Menu_* m, void* d){
 	saveLogbook();
 
@@ -129,14 +138,15 @@ void cb_mnuNewLogbook(Fl_Menu_* m, void* d){
 	dlgLogbook->label(fl_filename_name(logbook_filename.c_str()));
 	progdefaults.changed = true;
 	qsodb.deleteRecs();
+	dxcc_entity_cache_clear();
 	wBrowser->clear();
 	clearRecord();
 }
 
 void cb_mnuOpenLogbook(Fl_Menu_* m, void* d)
 {
-	const char* p = FSEL::select("Open logbook file", "ADIF\t*." ADIF_SUFFIX,
-						logbook_filename.c_str());
+	const char* p = FSEL::select(_("Open logbook file"), "ADIF\t*." ADIF_SUFFIX,
+				     logbook_filename.c_str());
 	if (p) {
 		saveLogbook();
 		qsodb.deleteRecs();
@@ -145,6 +155,8 @@ void cb_mnuOpenLogbook(Fl_Menu_* m, void* d)
 		progdefaults.logbookfilename = logbook_filename;
 		progdefaults.changed = true;
 		adifFile.readFile (logbook_filename.c_str(), &qsodb);
+		dxcc_entity_cache_clear();
+		dxcc_entity_cache_add(qsodb);
 		qsodb.isdirty(0);
 		loadBrowser();
 		dlgLogbook->label(fl_filename_name(logbook_filename.c_str()));
@@ -152,21 +164,23 @@ void cb_mnuOpenLogbook(Fl_Menu_* m, void* d)
 }
 
 void cb_mnuSaveLogbook(Fl_Menu_*m, void* d) {
-	const char* p = FSEL::saveas("Save logbook file", "ADIF\t*." ADIF_SUFFIX,
+	const char* p = FSEL::saveas(_("Save logbook file"), "ADIF\t*." ADIF_SUFFIX,
 				     logbook_filename.c_str());
 	if (p) {
 		logbook_filename = p;
 		dlgLogbook->label(fl_filename_name(logbook_filename.c_str()));
 		if (adifFile.writeLog (p, &qsodb))
-			fl_message ("Could not write to %s", p);
+			fl_alert2(_("Could not write to %s"), p);
 		qsodb.isdirty(0);
 	}
 }
 
 void cb_mnuMergeADIF_log(Fl_Menu_* m, void* d) {
-	const char* p = FSEL::select("Merge ADIF file", "ADIF\t*." ADIF_SUFFIX);
+	const char* p = FSEL::select(_("Merge ADIF file"), "ADIF\t*." ADIF_SUFFIX);
 	if (p) {
 		adifFile.readFile (p, &qsodb);
+		dxcc_entity_cache_clear();
+		dxcc_entity_cache_add(qsodb);
 		loadBrowser();
 		qsodb.isdirty(1);
 	}
@@ -220,16 +234,16 @@ static State logState = VIEWREC;
 void activateButtons() {
 	
 	if (logState == NEWREC) {
-		bNewSave->label ("Save");
-		bUpdateCancel->label ("Cancel");
+		bNewSave->label(_("Save"));
+		bUpdateCancel->label(_("Cancel"));
 		bDelete->deactivate ();
 		bSearchNext->deactivate ();
 		bSearchPrev->deactivate ();
 		inpDate_log->take_focus();
 		return;
 	}
-	bNewSave->label("New");
-	bUpdateCancel->label("Update");
+	bNewSave->label(_("New"));
+	bUpdateCancel->label(_("Update"));
 	bDelete->activate();
 	bSearchNext->activate ();
 	bSearchPrev->activate ();
@@ -481,6 +495,7 @@ cQsoRec rec;
 	qsodb.isdirty(0);
 	
 	qsodb.qsoNewRec (&rec);
+	dxcc_entity_cache_add(&rec);
 }
 
 void updateRecord() {
@@ -513,17 +528,20 @@ cQsoRec rec;
 	rec.putField(CQZ, inpCQZ_log->value());
 	rec.putField(ITUZ, inpITUZ_log->value());
 	rec.putField(TX_PWR, inpTX_pwr_log->value());
+	dxcc_entity_cache_rm(qsodb.getRec(editNbr));
 	qsodb.qsoUpdRec (editNbr, &rec);
+	dxcc_entity_cache_add(&rec);
 	adifFile.writeLog (logbook_filename.c_str(), &qsodb);
 	qsodb.isdirty(0);
 	loadBrowser(true);
 }
 
 void deleteRecord () {
-	if (qsodb.nbrRecs() == 0 || fl_choice("Really delete record for \"%s\"?\n",
-					      "Yes", "No", NULL, wBrowser->valueAt(-1, 2)))
+	if (qsodb.nbrRecs() == 0 || fl_choice2(_("Really delete record for \"%s\"?"),
+					       _("Yes"), _("No"), NULL, wBrowser->valueAt(-1, 2)))
 		return;
 
+	dxcc_entity_cache_rm(qsodb.getRec(editNbr));
 	qsodb.qsoDelRec(editNbr);
 	adifFile.writeLog (logbook_filename.c_str(), &qsodb);
 	qsodb.isdirty(0);
@@ -997,3 +1015,71 @@ SOAPBOX: \n\n",
     fclose (cabFile);
     return;
 }
+
+
+#include <tr1/unordered_map>
+typedef tr1::unordered_map<string, unsigned> dxcc_entity_cache_t;
+static dxcc_entity_cache_t dxcc_entity_cache;
+static bool dxcc_entity_cache_enabled = false;
+
+#include "dxcc.h"
+
+static void dxcc_entity_cache_clear(void)
+{
+	if (dxcc_entity_cache_enabled)
+		dxcc_entity_cache.clear();
+}
+
+static void dxcc_entity_cache_add(cQsoRec* r)
+{
+	if (!dxcc_entity_cache_enabled | !r)
+		return;
+
+	const dxcc* e = dxcc_lookup(r->getField(CALL));
+	if (e)
+		dxcc_entity_cache[e->country]++;
+}
+static void dxcc_entity_cache_add(cQsoDb& db)
+{
+	if (!dxcc_entity_cache_enabled)
+		return;
+
+	int n = db.nbrRecs();
+	for (int i = 0; i < n; i++)
+		dxcc_entity_cache_add(db.getRec(i));
+	if (!dxcc_entity_cache.empty())
+		LOG_INFO("Found %" PRIuSZ " countries in %d QSO records",
+			 dxcc_entity_cache.size(), n);
+}
+
+static void dxcc_entity_cache_rm(cQsoRec* r)
+{
+	if (!dxcc_entity_cache_enabled || !r)
+		return;
+
+	const dxcc* e = dxcc_lookup(r->getField(CALL));
+	if (!e)
+		return;
+	dxcc_entity_cache_t::iterator i = dxcc_entity_cache.find(e->country);
+	if (i != dxcc_entity_cache.end()) {
+		if (i->second)
+			i->second--;
+		else
+			dxcc_entity_cache.erase(i);
+	}
+}
+
+void dxcc_entity_cache_enable(bool v)
+{
+	if (dxcc_entity_cache_enabled == v)
+		return;
+
+	dxcc_entity_cache_clear();
+	if ((dxcc_entity_cache_enabled = v))
+		dxcc_entity_cache_add(qsodb);
+}
+
+bool qsodb_dxcc_entity_find(const char* country)
+{
+	return dxcc_entity_cache.find(country) != dxcc_entity_cache.end();
+}
