@@ -1,15 +1,17 @@
 // textio.cxx
 
 #include <config.h>
-#include <string>
-#include <iostream>
 
-using namespace std;
+#include <string>
+#include <cstdio>
+#include <cstring>
 
 #include "textio.h"
 #include "lgbook.h"
 
-#ifdef __CYGWIN__
+using namespace std;
+
+#ifdef __WOE32__
 static const char *szEOL = "\r\n";
 #else
 static const char *szEOL = "\n";
