@@ -26,7 +26,7 @@
 
 #include <sys/types.h>
 #include <sys/stat.h>
-#if !defined(__CYGWIN__) && !defined(__APPLE__)
+#if !defined(__WOE32__) && !defined(__APPLE__)
 #  include <sys/ipc.h>
 #  include <sys/msg.h>
 #endif
@@ -37,17 +37,21 @@
 #include "lgbook.h"
 #include "main.h"
 #include "modem.h"
+#include "waterfall.h"
+#include "fl_digi.h"
+#include "trx.h"
 #include "debug.h"
 #include "macros.h"
 #include "status.h"
 #include "spot.h"
-
 #include "adif_io.h"
 
 #include "logsupport.h"
 
 #include <FL/fl_ask.H>
 
+using namespace std;
+
 //---------------------------------------------------------------------
 const char *logmode;
 char logdate[32];
@@ -59,7 +63,7 @@ static string notes;
 
 //=============================================================================
 
-#if defined(__CYGWIN__) || defined(__APPLE__)
+#if defined(__WOE32__) || defined(__APPLE__)
 
 static string adif;
 
@@ -83,7 +87,7 @@ void putadif(int num, const char *s)
         char tempstr[100];
         int slen = strlen(s);
         if (slen > fields[num].size) slen = fields[num].size;
-        int n = snprintf(tempstr, sizeof(tempstr), "<%s:%zu>", fields[num].name, slen);
+        int n = snprintf(tempstr, sizeof(tempstr), "<%s:%d>", fields[num].name, slen);
         if (n == -1) {
 		LOG_PERROR("snprintf");
                 return;
@@ -136,7 +140,7 @@ void submit_ADIF(void)
 // the following IPC message is compatible with xlog remote data spec.
 //---------------------------------------------------------------------
 
-#if !defined(__CYGWIN__) && !defined(__APPLE__)
+#if !defined(__WOE32__) && !defined(__APPLE__)
 
 #define addtomsg(x, y)	log_msg = log_msg + (x) + (y) + LOG_MSEPARATOR
 
@@ -176,18 +180,13 @@ static void send_IPC_log(void)
 	msgbuf.mtext[sizeof(msgbuf.mtext) - 1] = '\0';
 
 	if ((msqid = msgget(LOG_MKEY, 0666 | IPC_CREAT)) == -1) {
-		errmsg = "msgget: ";
-		errmsg.append(strerror(errno));
-		LOG_ERROR("%s", errmsg.c_str());
-		fl_message(errmsg.c_str());
+		LOG_PERROR("msgget");
 		return;
 	}
 	msgbuf.mtype = LOG_MTYPE;
 	len = strlen(msgbuf.mtext) + 1;
-	if (msgsnd(msqid, &msgbuf, len, IPC_NOWAIT) < 0) {
-		errmsg = "msgsnd: ";
-		fl_message(errmsg.c_str());
-	}
+	if (msgsnd(msqid, &msgbuf, len, IPC_NOWAIT) < 0)
+		LOG_PERROR("msgsnd");
 }
 
 #endif
@@ -210,7 +209,7 @@ void submit_log(void)
 
 	AddRecord();
 
-#if !defined(__CYGWIN__) && !defined(__APPLE__)
+#if !defined(__WOE32__) && !defined(__APPLE__)
 	send_IPC_log();
 #else
 	submit_ADIF();
