@@ -29,13 +29,26 @@
 #include <cstdlib>
 #include <getopt.h>
 #include <sys/types.h>
-#if !defined(__CYGWIN__) && !defined(__APPLE__)
+
+#if !defined(__WOE32__) && !defined(__APPLE__)
 #  include <sys/ipc.h>
 #  include <sys/msg.h>
 #endif
-#include <sys/utsname.h>
+
+#ifdef __MINGW32__
+#  include "compat.h"
+#endif
+
+#include <sys/stat.h>
+
+#if HAVE_SYS_UTSNAME_H
+#  include <sys/utsname.h>
+#endif
+
 #include <unistd.h>
-#include <dirent.h>
+#ifndef __MINGW32__
+#  include <dirent.h>
+#endif
 #include <exception>
 #include <signal.h>
 #include <locale.h>
@@ -45,19 +58,22 @@
 #include <FL/Fl_Window.H>
 #include <FL/Fl_Shared_Image.H>
 #include <FL/x.H>
+#ifdef __MINGW32__
+#  define dirent fl_dirent_no_thanks
+#endif
+#include <FL/filename.H>
+#ifdef __MINGW32__
+#  undef dirent
+#endif
 
 #include "gettext.h"
 #include "main.h"
 #include "waterfall.h"
-#include "fft.h"
+#include "trx.h"
 #include "soundconf.h"
-#include "complex.h"
 #include "fl_digi.h"
 #include "rigio.h"
 #include "globals.h"
-#include "psk.h"
-#include "cw.h"
-#include "mfsk.h"
 #include "confdialog.h"
 #include "colorsfonts.h"
 #include "configuration.h"
@@ -67,6 +83,7 @@
 #include "timeops.h"
 #include "debug.h"
 #include "pskrep.h"
+#include "notify.h"
 #include "logbook.h"
 #include "dxcc.h"
 #include "newinstall.h"
@@ -130,7 +147,7 @@ int		rxmsgid = -1;
 TXMSGSTRUC txmsgst;
 int txmsgid = -1;
 
-string option_help, version_text;
+string option_help, version_text, build_text;
 
 qrunner *cbq[NUM_QRUNNER_THREADS];
 
@@ -166,7 +183,7 @@ int main(int argc, char ** argv)
 
 	{
 		char dirbuf[FL_PATH_MAX + 1];
-#ifdef __CYGWIN__
+#ifdef __WOE32__
 		fl_filename_expand(dirbuf, sizeof(dirbuf) - 1, "$USERPROFILE/fldigi.files/");
 #else
 		fl_filename_expand(dirbuf, sizeof(dirbuf) - 1, "$HOME/.fldigi/");
@@ -194,6 +211,7 @@ int main(int argc, char ** argv)
 		debug::start(string(HomeDir).append("status_log.txt").c_str());
 		time_t t = time(NULL);
 		LOG(debug::QUIET_LEVEL, debug::LOG_OTHER, _("%s log started on %s"), PACKAGE_STRING, ctime(&t));
+		LOG_THREAD_ID();
 	}
 	catch (const char* error) {
 		cerr << error << '\n';
@@ -203,7 +221,7 @@ int main(int argc, char ** argv)
 	xmlfname = HomeDir; 
 	xmlfname.append("rig.xml");
 
-#if !defined(__CYGWIN__) && !defined(__APPLE__)
+#if !defined(__WOE32__) && !defined(__APPLE__)
    	txmsgid = msgget( (key_t) progdefaults.tx_msgid, 0666 );
 #else
 	txmsgid = -1;
@@ -256,7 +274,12 @@ int main(int argc, char ** argv)
 	    lfname.append(".log");
 	    logfile = new cLogfile(lfname);
 	    logfile->log_to_file_start();
-    }
+	}
+
+	dxcc_open(string(HomeDir).append("cty.dat").c_str());
+	qsl_open(string(HomeDir).append("lotw1.txt").c_str(), QSL_LOTW);
+	if (!qsl_open(string(HomeDir).append("eqsl.txt").c_str(), QSL_EQSL))
+		qsl_open(string(HomeDir).append("AGMemberList.txt").c_str(), QSL_EQSL);
 
 	Fl::scheme(progdefaults.ui_scheme.c_str());
 	progdefaults.initFonts();
@@ -314,13 +337,7 @@ int main(int argc, char ** argv)
 		if (!pskrep_start())
 			LOG_ERROR("Could not start PSK reporter: %s", pskrep_error());
 
-	if (progdefaults.rxtext_tooltips || progdefaults.autofill_qso_fields)
-		dxcc_open(string(HomeDir).append("cty.dat").c_str());
-	if (progdefaults.rxtext_tooltips) {
-		qsl_open(string(HomeDir).append("lotw1.txt").c_str(), QSL_LOTW);
-		if (!qsl_open(string(HomeDir).append("eqsl.txt").c_str(), QSL_EQSL))
-			qsl_open(string(HomeDir).append("AGMemberList.txt").c_str(), QSL_EQSL);
-	}
+	notify_start();
 
 	int ret = Fl::run();
 
@@ -354,7 +371,7 @@ void generate_option_help(void) {
 	     << "    Look for configuration files in DIRECTORY\n"
 	     << "    The default is: " << HomeDir << "\n\n"
 
-#if !defined(__CYGWIN__) && !defined(__APPLE__)
+#if !defined(__WOE32__) && !defined(__APPLE__)
 	     << "  --rx-ipc-key KEY\n"
 	     << "    Set the receive message queue key\n"
 	     << "    May be given in hex if prefixed with \"0x\"\n"
@@ -435,6 +452,9 @@ void generate_option_help(void) {
 	     << "  --version\n"
 	     << "    Print version information\n\n"
 
+	     << "  --build-info\n"
+	     << "    Print build information\n\n"
+
 	     << "  --help\n"
 	     << "    Print this option help\n\n";
 
@@ -496,7 +516,7 @@ int parse_args(int argc, char **argv, int& idx)
 		return 0;
 
         enum { OPT_ZERO,
-#ifndef __CYGWIN__
+#ifndef __WOE32__
 	       OPT_RX_IPC_KEY, OPT_TX_IPC_KEY,
 #endif
 	       OPT_CONFIG_DIR,
@@ -520,11 +540,11 @@ int parse_args(int argc, char **argv, int& idx)
 #endif
 	       OPT_DEBUG_LEVEL,
                OPT_EXIT_AFTER,
-               OPT_DEPRECATED, OPT_HELP, OPT_VERSION };
+               OPT_DEPRECATED, OPT_HELP, OPT_VERSION, OPT_BUILD_INFO };
 
 	const char shortopts[] = "+";
 	static struct option longopts[] = {
-#ifndef __CYGWIN__
+#ifndef __WOE32__
 		{ "rx-ipc-key",	   1, 0, OPT_RX_IPC_KEY },
 		{ "tx-ipc-key",	   1, 0, OPT_TX_IPC_KEY },
 #endif
@@ -572,6 +592,7 @@ int parse_args(int argc, char **argv, int& idx)
 
 		{ "help",	   0, 0, OPT_HELP },
 		{ "version",	   0, 0, OPT_VERSION },
+		{ "build-info",	   0, 0, OPT_BUILD_INFO },
 		{ 0 }
 	};
 
@@ -586,7 +607,7 @@ int parse_args(int argc, char **argv, int& idx)
 			// handle options with non-0 flag here
 			return 0;
 
-#if !defined(__CYGWIN__) && !defined(__APPLE__)
+#if !defined(__WOE32__) && !defined(__APPLE__)
 		case OPT_RX_IPC_KEY: case OPT_TX_IPC_KEY:
 		{
 			errno = 0;
@@ -744,6 +765,10 @@ int parse_args(int argc, char **argv, int& idx)
 			cout << version_text;
 			exit(EXIT_SUCCESS);
 
+		case OPT_BUILD_INFO:
+			cout << build_text;
+			exit(EXIT_SUCCESS);
+
 		case '?': default:
 			cerr << "Try `" << PACKAGE_NAME << " --help' for more information.\n";
 			exit(EXIT_FAILURE);
@@ -765,59 +790,71 @@ int parse_args(int argc, char **argv, int& idx)
 
 void generate_version_text(void)
 {
-	ostringstream s;
-	s << PACKAGE_STRING << '\n'
-	  << "Copyright (c) 2008 " PACKAGE_AUTHORS "\n" <<
-	   _("License GPLv2+: GNU GPL version 2 or later <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>\n"
-	     "This is free software: you are free to change and redistribute it.\n"
-	     "There is NO WARRANTY, to the extent permitted by law.\n");
+	version_text.assign(PACKAGE_STRING "\nCopyright (C) 2008, 2009 " PACKAGE_AUTHORS ".\n");
+	version_text.append(_("License GPLv2+: GNU GPL version 2 or later "
+			      "<http://www.gnu.org/licenses/gpl-2.0.html>\n"
+			      "This is free software: you are free to change and redistribute it.\n"
+			      "There is NO WARRANTY, to the extent permitted by law.\n"));
 
-	s << _("\nSystem: ");
+	ostringstream s;
+	s << "Build information:\n";
+	s << "  built          : " << BUILD_DATE << " by " << BUILD_USER
+	  << '@' << BUILD_HOST << " on " << BUILD_BUILD_PLATFORM
+	  << " for " << BUILD_TARGET_PLATFORM << "\n\n"
+	  << "  configure flags: " << BUILD_CONFIGURE_ARGS << "\n\n"
+	  << "  compiler       : " << BUILD_COMPILER << "\n\n"
+	  << "  compiler flags : " << FLDIGI_BUILD_CXXFLAGS << "\n\n"
+	  << "  linker flags   : " << FLDIGI_BUILD_LDFLAGS << "\n\n"
+
+	  << "  libraries      : " "FLTK " FLTK_BUILD_VERSION "\n"
+	  << "                   " "libsamplerate " << SAMPLERATE_BUILD_VERSION "\n";
+#if USE_SNDFILE
+	s << "                   " "libsndfile " << SNDFILE_BUILD_VERSION "\n";
+#endif
+#if USE_PORTAUDIO
+	s << "                   " "PortAudio " << PORTAUDIO_BUILD_VERSION "\n";
+#endif
+#if USE_PULSEAUDIO
+	s << "                   " "PulseAudio " << PULSEAUDIO_BUILD_VERSION "\n";
+#endif
+#if USE_HAMLIB
+	s << "                   " "Hamlib " << HAMLIB_BUILD_VERSION "\n";
+#endif
+#if USE_XMLRPC
+	s << "                   " "XMLRPC-C " << XMLRPC_BUILD_VERSION "\n\n";
+#endif
+
+	s << "\nRuntime information:\n";
         struct utsname u;
         if (uname(&u) != -1) {
-		s << u.sysname << ' ' << u.nodename
-		  << ' ' << u.release << ' ' << u.version << ' '
-		  << u.machine << '\n';
+		s << "  system         : " << u.sysname << ' ' << u.nodename
+		  << ' ' << u.release << ' ' << u.version << ' ' << u.machine << "\n\n";
 	}
 
-#include "versions.h"
-#ifdef HAVE_VERSIONS_H
-	s /*<< "\nConfigured with: " << COMPILE_CFG*/ << '\n'
-	    << "Built on " << COMPILE_DATE << " by " << COMPILE_USER
-	    << '@' << COMPILE_HOST << " with:\n"
-	    << COMPILER << '\n'
-	    << "CFLAGS=" << CFLAGS << '\n'
-	    << "LDFLAGS=" << LDFLAGS << '\n';
-#endif // HAVE_VERSIONS_H
-
-	s << "Libraries:\n"
-	  << "FLTK " << FL_MAJOR_VERSION << '.' << FL_MINOR_VERSION << '.'
-	  << FL_PATCH_VERSION << '\n';
-
-	s << src_get_version() << '\n';
-
-#if USE_HAMLIB
-	s << hamlib_version << '\n';
-#endif
-
-#if USE_PORTAUDIO
-	s << Pa_GetVersionText() << ' ' << Pa_GetVersion() << '\n';
-#endif
-
+	s << "  libraries      : " << src_get_version() << '\n';
 #if USE_SNDFILE
 	char sndfile_version[32];
 	sf_command(NULL, SFC_GET_LIB_VERSION, sndfile_version, sizeof(sndfile_version));
-	s << sndfile_version << '\n';
+	s << "                   " << sndfile_version << '\n';
+#endif
+#if USE_PORTAUDIO
+	s << "                   " << Pa_GetVersionText() << ' ' << Pa_GetVersion() << '\n';
+#endif
+#if USE_PULSEAUDIO
+	s << "                   " << "Pulseaudio " << pa_get_library_version() << '\n';
+#endif
+#if USE_HAMLIB
+	s << "                   " << hamlib_version << '\n';
 #endif
 
-	version_text = s.str();
+	build_text = s.str();
 }
 
 // When debugging is enabled, reexec with malloc debugging hooks enabled, unless
 // the env var FLDIGI_NO_EXEC is set, or our parent process is gdb.
 void debug_exec(char** argv)
 {
-#if !defined(NDEBUG) && !defined(__CYGWIN__)
+#if !defined(NDEBUG) && defined(__GLIBC__)
         if (getenv("FLDIGI_NO_EXEC"))
                 return;
 
@@ -847,7 +884,7 @@ void set_platform_ui(void)
        progdefaults.WaterfallFontsize = 12;
        progdefaults.RxFontsize = 12;
        progdefaults.TxFontsize = 12;
-#elif defined(__CYGWIN__)
+#elif defined(__WOE32__)
        Fl::set_font(FL_HELVETICA, "Tahoma");
        FL_NORMAL_SIZE = 11;
        progdefaults.WaterfallFontnbr = FL_HELVETICA;
@@ -905,7 +942,7 @@ double speed_test(int converter, unsigned repeat)
 
 static void setup_signal_handlers(void)
 {
-#if !defined(__CYGWIN__) && !defined(__MINGW32__)
+#ifndef __WOE32__
 	struct sigaction action;
 	memset(&action, 0, sizeof(struct sigaction));
 
@@ -934,40 +971,6 @@ static void setup_signal_handlers(void)
 #endif
 }
 
-#ifdef ENABLE_NLS
-int setup_nls(void)
-{
-	static int nls_set_up = 0;
-	if (nls_set_up)
-		return nls_set_up;
-
-	setlocale (LC_MESSAGES, "");
-	setlocale (LC_CTYPE, "C");
-	setlocale (LC_TIME, "");
-	// setting LC_NUMERIC might break the config read/write routines
-
-	const char* ldir;
-	char buf[4096];
-	if (!(ldir = getenv("FLDIGI_LOCALE_DIR"))) {
-		if (getcwd(buf, sizeof(buf) - strlen("/locale") - 1)) {
-			strcpy(buf + strlen(buf), "/locale");
-			struct stat s;
-			if (stat(buf, &s) != -1 && S_ISDIR(s.st_mode))
-				ldir = buf;
-			else
-				ldir = LOCALEDIR;
-		}
-	}
-
-	bindtextdomain(PACKAGE, ldir);
-	/* fltk-1.1.x only knows about Latin-1 */
-	bind_textdomain_codeset(PACKAGE, "ISO-8859-1");
-	textdomain(PACKAGE);
-
-	return nls_set_up = 1;
-}
-#endif
-
 static void checkdirectories(void)
 {
 	struct {
@@ -991,7 +994,7 @@ static void checkdirectories(void)
 	int r;
 	for (size_t i = 0; i < sizeof(dirs)/sizeof(*dirs); i++) {
 		if (dirs[i].suffix)
-			dirs[i].dir.assign(HomeDir).append(dirs[i].suffix).append("/");
+			dirs[i].dir.assign(HomeDir).append(dirs[i].suffix).append(PATH_SEP);
 
 		if ((r = mkdir(dirs[i].dir.c_str(), 0777)) == -1 && errno != EEXIST) {
 			cerr << _("Could not make directory") << ' ' << dirs[i].dir
