@@ -30,9 +30,14 @@
 #include <cstring>
 #include <libgen.h>
 
+#include <FL/Fl.H>
+
 #include "mfsk.h"
 #include "modem.h"
 
+#include "misc.h"
+#include "main.h"
+#include "fl_digi.h"
 #include "configuration.h"
 #include "status.h"
 #include "trx.h"
@@ -687,15 +692,9 @@ int mfsk::rx_process(const double *buf, int len)
 				}
 				rxstate = RX_STATE_DATA;
 				put_status("");
-#if USE_LIBPNG
+
 				string autosave_dir = PicsDir;
 				picRx->save_png(autosave_dir.c_str());
-#else
-#  if USE_LIBJPEG
-				string autosave_dir = PicsDir;
-				picRx->save_jpeg(autosave_dir.c_str());
-#  endif
-#endif
 			} else
 				recvpic(z);
 			continue;
