@@ -26,6 +26,10 @@
 
 #include <config.h>
 
+#ifdef __MINGW32__
+#  include "compat.h"
+#endif
+
 #include <fstream>
 #include <string>
 #include <cstdlib>
@@ -33,7 +37,7 @@
 #include <errno.h>
 
 #include <sys/types.h>
-#if !defined(__CYGWIN__) && !defined(__APPLE__)
+#if !defined(__WOE32__) && !defined(__APPLE__)
 #  include <sys/ipc.h>
 #  include <sys/msg.h>
 #endif
@@ -43,6 +47,7 @@
 #include "main.h"
 #include "configuration.h"
 #include "fl_digi.h"
+#include "trx.h"
 #include "arq_io.h"
 
 #include "threads.h"
@@ -71,11 +76,6 @@ static void set_button(Fl_Button* button, bool value)
 	button->do_callback();
 }
 
-static void popup_msg(void* msg)
-{
-	fl_message((const char*)msg);
-}
-
 void ParseMode(string src)
 {
 	if (src.find("PTTTUNE") != string::npos) {
@@ -108,9 +108,9 @@ void parse_arqtext(string &toparse)
 
 	idxCmd = toparse.find("<cmd>");
 	idxCmdEnd = toparse.find("</cmd>");
-	
+
 	if ( idxCmd != string::npos && idxCmdEnd != string::npos && idxCmdEnd > idxCmd ) {
-		
+
 LOG_DEBUG("Command string: %s", toparse.substr(idxCmd, idxCmdEnd + 6).c_str());
 		strCmdText = toparse.substr(idxCmd + 5, idxCmdEnd - idxCmd - 5);
 		if (strCmdText == "server" && mailserver == false && mailclient == false) {
@@ -148,7 +148,7 @@ LOG_DEBUG("ARQ is reset to normal ops");
 		} else {
 			if ((idxSubCmd = strCmdText.find("<mode>")) != string::npos) {
 				idxSubCmdEnd = strCmdText.find("</mode>");
-				if (	idxSubCmdEnd != string::npos && 
+				if (	idxSubCmdEnd != string::npos &&
 						idxSubCmdEnd > idxSubCmd ) {
 					strSubCmd = strCmdText.substr(idxSubCmd + 6, idxSubCmdEnd - idxSubCmd - 6);
 					ParseMode(strSubCmd);
@@ -169,12 +169,12 @@ bool bSend0x06 = false;
 // SysV ARQ used only on Linux / Free-BSD or Unix type OS
 //-----------------------------------------------------------------------------
 
-#if !defined(__CYGWIN__) && !defined(__APPLE__)
+#if !defined(__WOE32__) && !defined(__APPLE__)
 void process_msgque()
 {
 	memset(txmsgst.buffer, 0, ARQBUFSIZ);
 	int nbytes = msgrcv (txmsgid, (void *)&txmsgst, ARQBUFSIZ, 0, IPC_NOWAIT);
-	if (nbytes > 0) { 
+	if (nbytes > 0) {
 		txstring.append(txmsgst.buffer);
 		parse_arqtext(txstring);
 
@@ -208,8 +208,8 @@ bool SysV_arqRx()
 //-----------------------------------------------------------------------------
 // checkTLF
 // look for files named
-//    TLFfldigi ==> tlfio is true and
-//              ==> mailclient is true
+//	TLFfldigi ==> tlfio is true and
+//			  ==> mailclient is true
 // in $HOME
 
 void checkTLF() {
@@ -218,10 +218,10 @@ void checkTLF() {
 	ifstream testFile;
 
 	tlfio = mailserver = mailclient = false;
-	
-	TLFfile = PskMailDir;	
+
+	TLFfile = PskMailDir;
 	TLFfile += "TLFfldigi";
-	
+
 	testFile.open(TLFfile.c_str());
 	if (testFile.is_open()) {
 		testFile.close();
@@ -236,27 +236,27 @@ void checkTLF() {
 
 bool TLF_arqRx()
 {
-    time_t start_time, prog_time;
+	time_t start_time, prog_time;
 	static char mailline[1000];
-    string sAutoFile = PskMailDir;
+	string sAutoFile = PskMailDir;
 	sAutoFile += "gmfsk_autofile";
 
 	ifstream autofile(sAutoFile.c_str());
 	if(autofile) {
 		arqtext = "";
-        time(&start_time);
+		time(&start_time);
 		while (!autofile.eof()) {
 			memset(mailline,0,1000);
 			autofile.getline(mailline, 998); // leave space for "\n" and null byte
 			txstring.append(mailline);
 			txstring.append("\n");
-            time(&prog_time);
-            if (prog_time - start_time > TIMEOUT) {
+			time(&prog_time);
+			if (prog_time - start_time > TIMEOUT) {
 				LOG_ERROR("TLF file_i/o failure");
-                autofile.close();
-                std::remove (sAutoFile.c_str());
-                return false;
-            }
+				autofile.close();
+				std::remove (sAutoFile.c_str());
+				return false;
+			}
 		}
 		autofile.close();
 		std::remove (sAutoFile.c_str());
@@ -328,7 +328,7 @@ bool ARQ_SOCKET_Server::start(const char* node, const char* service)
 	try {
 		inst->server_socket->open(Address(node, service));
 		inst->server_socket->bind();
-#if defined(__CYGWIN__)
+#ifdef __WOE32__
 		inst->server_socket->listen();
 		inst->server_socket->set_timeout(0.1);
 #endif
@@ -339,7 +339,6 @@ bool ARQ_SOCKET_Server::start(const char* node, const char* service)
 		if (e.error() == EADDRINUSE)
 			errstring.append("\nMultiple instances of fldigi??");
 		LOG_ERROR("%s", errstring.c_str());
-		fl_message(errstring.c_str());
 
 		delete arq_socket_thread;
 		arq_socket_thread = 0;
@@ -369,7 +368,7 @@ void* ARQ_SOCKET_Server::thread_func(void*)
 	// On woe32 we block for a short time and test for cancellation.
 	while (inst->run) {
 		try {
-#if defined(__CYGWIN__)
+#ifdef __WOE32__
 			if (inst->server_socket->wait(0))
 #endif
 				arq_run(inst->server_socket->accept());
@@ -379,7 +378,6 @@ void* ARQ_SOCKET_Server::thread_func(void*)
 			if (e.error() != EINTR) {
 				errstring = e.what();
 				LOG_ERROR("%s", errstring.c_str());
-				Fl::add_timeout(0.0, popup_msg, (void*)errstring.c_str());
 				break;
 			}
 		}
@@ -404,6 +402,7 @@ void arq_run(Socket s)
 
 void arq_stop()
 {
+	arqclient.close();
 	isSocketConnected = false;
 	arqmode = false;
 }
@@ -423,14 +422,14 @@ void WriteARQsocket(unsigned int data)
 bool Socket_arqRx()
 {
 	if (!isSocketConnected) return false;
-	
+
 	string instr;
 
 	try {
 		size_t n = arqclient.recv(instr);
 		if ( n > 0)
 			txstring.append(instr);
-			
+
 		if (progdefaults.rsid == true) {
 			send0x06();
 			arqtext.clear();
@@ -438,7 +437,7 @@ bool Socket_arqRx()
 			cmdstring.clear();
 			return true;
 		}
-	
+
 		if (arqtext.empty() && !txstring.empty()) {
 			arqtext = txstring;
 			parse_arqtext(arqtext);
@@ -465,7 +464,7 @@ LOG_DEBUG(txstring.c_str());
 //-----------------------------------------------------------------------------
 // Send ARQ characters to ARQ client
 //-----------------------------------------------------------------------------
-#if !defined(__CYGWIN__) && !defined(__APPLE__)
+#if !defined(__WOE32__) && !defined(__APPLE__)
 void WriteARQSysV(unsigned int data)
 {
 	rxmsgid = msgget( (key_t) progdefaults.rx_msgid, 0666);
@@ -480,7 +479,7 @@ void WriteARQSysV(unsigned int data)
 void WriteARQ( unsigned int data)
 {
 	WriteARQsocket(data);
-#if !defined(__CYGWIN__) && !defined(__APPLE__)
+#if !defined(__WOE32__) && !defined(__APPLE__)
 	WriteARQSysV(data);
 #endif
 }
@@ -511,23 +510,11 @@ void send0x06()
 	}
 }
 
-char arq_get_char()
-{
-	if (pText != arqtext.length()-1) //arqtext.end())
-		return arqtext[pText++];
-//		return *pText++;
-
-	arqtext.clear();
-	pText = 0;
-	bSend0x06 = true;
-//	arq_text_available = false;
-	return 0x03; // tells psk modem to return to rx
-}
-
 // ============================================================================
 // Implementation using thread vice the fldigi timeout facility
 // ============================================================================
 static pthread_t arq_thread;
+static pthread_mutex_t arq_mutex = PTHREAD_MUTEX_INITIALIZER;
 
 static void *arq_loop(void *args);
 
@@ -543,17 +530,21 @@ static void *arq_loop(void *args)
 		if (arq_exit)
 			break;
 
+		pthread_mutex_lock (&arq_mutex);
+
 		if (bSend0x06)
 			send0x06();
 
-#if !defined(__CYGWIN__) && !defined(__APPLE__)
+#if !defined(__WOE32__) && !defined(__APPLE__)
 		// order of precedence; Socket, SysV, GMFSKfile
 		if (!Socket_arqRx() && !SysV_arqRx() && tlfio)
 			TLF_arqRx();
 #else
 		Socket_arqRx();
 #endif
+		pthread_mutex_unlock (&arq_mutex);
 		MilliSleep(50);
+
 	}
 // exit the arq thread
 	return NULL;
@@ -562,17 +553,17 @@ static void *arq_loop(void *args)
 void arq_init()
 {
 	arq_enabled = false;
-	
+
 	txstring.clear();
 	cmdstring.clear();
-	
+
 	if (!ARQ_SOCKET_Server::start( progdefaults.arq_address.c_str(), progdefaults.arq_port.c_str() ))
 		return;
 
 	if (pthread_create(&arq_thread, NULL, arq_loop, NULL) < 0) {
-		fl_message("arq init: pthread_create failed");
+		LOG_ERROR("arq init: pthread_create failed");
 		return;
-	} 
+	}
 
 	arq_enabled = true;
 }
@@ -592,3 +583,19 @@ void arq_close(void)
 
 	arq_exit = false;
 }
+
+char arq_get_char()
+{
+	char c = 0x03;
+	pthread_mutex_lock (&arq_mutex);
+	if (pText != arqtext.length()-1) {
+		c = arqtext[pText++];
+	} else {
+		arqtext.clear();
+		pText = 0;
+		bSend0x06 = true;
+	}
+	pthread_mutex_unlock (&arq_mutex);
+	return c;
+}
+
