@@ -4,9 +4,10 @@
 #include "confdialog.h"
 #include "xmlreader.h"
 #include "soundconf.h"
-#include "waterfall.h"
+#include "fl_digi.h"
 #include "main.h"
 #include "gettext.h"
+#include "icons.h"
 
 #if USE_HAMLIB
 	#include "hamlib.h"
@@ -14,16 +15,13 @@
 #endif
 
 #include "rigMEM.h"
-//#include "rigio.h"
 #include "debug.h"
 
 #include <FL/Fl_Tooltip.H>
 
 #include <unistd.h>
-
 #include <iostream>
 #include <fstream>
-
 #include <map>
 #include <sstream>
 
@@ -544,9 +542,9 @@ int configuration::setDefaults()
 
 void configuration::resetDefaults(void)
 {
-	if (!fl_choice(_("Reset all options to their default values?"), "OK", "Cancel", NULL) &&
+	if (!fl_choice2(_("Reset all options to their default values?"), "OK", "Cancel", NULL) &&
 	    Fl::event_key() != FL_Escape) {
-		fl_message(_("Reset options will take effect at the next start"));
+		fl_message2(_("Reset options will take effect at the next start"));
 		reset();
 		atexit(reset);
 	}
@@ -634,6 +632,12 @@ void configuration::initInterface()
 #endif
 	} else if (chkUSEXMLRPCis) {
 		wf->setXMLRPC(1);
+		rigCAT_init(false);
+		if (docked_rig_control)
+			qsoFreqDisp->activate();
+		wf->USB(true);
+		wf->setQSY(1);
+		riginitOK = true;
 	}
 
 	if (riginitOK == false) {
@@ -683,19 +687,43 @@ int configuration::BaudRate(size_t n)
 	return (atoi(szBaudRates[n + 1]));
 }
 
+#ifdef __WOE32__
+static bool open_serial(const char* dev)
+{
+	bool ret = false;
+#ifdef __CYGWIN__
+	int fd = open(dev, O_RDWR | O_NOCTTY | O_NDELAY);
+	if (fd != -1) {
+		close(fd);
+		ret = true;
+	}
+#elif defined(__MINGW32__)
+	HANDLE fd = CreateFile(dev, GENERIC_READ | GENERIC_WRITE, 0, 0, OPEN_EXISTING, 0, 0);
+	if (fd != INVALID_HANDLE_VALUE) {
+		CloseHandle(fd);
+		ret = true;
+	}
+#endif
+	return ret;
+}
+#endif // __WOE32__
+
 void configuration::testCommPorts()
 {
 	inpTTYdev->clear();
 	inpRIGdev->clear();
 	inpXmlRigDevice->clear();
-	
+
 #ifndef PATH_MAX
 #  define PATH_MAX 1024
 #endif
-#ifndef __CYGWIN__
+#ifndef __WOE32__
 	struct stat st;
 #endif
+
+#ifndef __APPLE__
 	char ttyname[PATH_MAX + 1];
+#endif
 
 #ifdef __linux__
 	bool ret = false;
@@ -737,6 +765,7 @@ out:
 		return;
 #endif // __linux__
 
+	// TODO: will the mingw probing work for cygwin too?
 
 	const char* tty_fmt[] = {
 #if defined(__linux__)
@@ -747,14 +776,15 @@ out:
 		"/dev/ttyd%u"
 #elif defined(__CYGWIN__)
 		"/dev/ttyS%u"
+#elif defined(__MINGW32__)
+		"//./COM%u"
 #elif defined(__APPLE__)
 		"/dev/cu.*",
 		"/dev/tty.*"
 #endif
 	};
 
-#if defined(__CYGWIN__)
-	int fd;
+#if defined(__WOE32__)
 #  define TTY_MAX 255
 #elif defined(__APPLE__)
 	glob_t gbuf;
@@ -766,15 +796,18 @@ out:
 #ifndef __APPLE__
 		for (unsigned j = 0; j < TTY_MAX; j++) {
 			snprintf(ttyname, sizeof(ttyname), tty_fmt[i], j);
-#  ifndef __CYGWIN__
+#  ifndef __WOE32__
 			if ( !(stat(ttyname, &st) == 0 && S_ISCHR(st.st_mode)) )
 				continue;
-#  else // __CYGWIN__
-			if ((fd = open(ttyname, O_RDWR | O_NOCTTY | O_NDELAY)) == -1)
+#  else // __WOE32__
+			if (!open_serial(ttyname))
 				continue;
+#    ifdef __CYGWIN__
 			snprintf(ttyname, sizeof(ttyname), "COM%u", j+1);
-			close(fd);
-#  endif // __CYGWIN__
+#    else
+			snprintf(ttyname, sizeof(ttyname), "COM%u", j);
+#    endif
+#  endif // __WOE32__
 
 			LOG_INFO("Found serial port %s", ttyname);
 			inpTTYdev->add(ttyname);
@@ -794,7 +827,7 @@ out:
 #  if USE_HAMLIB
 			inpRIGdev->add(gbuf.gl_pathv[j]);
 #  endif
-			inpXmlRigDevice->add(ttyname);
+			inpXmlRigDevice->add(gbuf.gl_pathv[j]);
 
 		}
 		globfree(&gbuf);
