@@ -22,6 +22,10 @@
 
 #include <config.h>
 
+#ifdef __MINGW32__
+#  include "compat.h"
+#endif
+
 #include <cstdio>
 #include <cstring>
 #include <cstdarg>
@@ -39,6 +43,7 @@
 #include "FTextView.h"
 
 #include "debug.h"
+#include "icons.h"
 #include "gettext.h"
 
 using namespace std;
@@ -50,9 +55,10 @@ static FILE* rfile;
 static size_t nlines = 0;
 static int rfd;
 static bool tty;
+static bool want_popup = true;
 
 static Fl_Double_Window* window;
-static FTextLog* text;
+static FTextView* text;
 
 debug* debug::inst = 0;
 debug::level_e debug::level = debug::WARN_LEVEL;
@@ -62,6 +68,7 @@ const char* prefix[] = { _("Quiet"), _("Error"), _("Warning"), _("Info"), _("Deb
 
 static void slider_cb(Fl_Widget* w, void*);
 static void src_menu_cb(Fl_Widget* w, void*);
+static void popup_message(void*);
 
 Fl_Menu_Item src_menu[] = {
 	{ _("Audio"), 0, 0, 0, FL_MENU_TOGGLE | FL_MENU_VALUE },
@@ -96,9 +103,10 @@ void debug::start(const char* filename)
 	slider->value(level);
 	slider->callback(slider_cb);
 
-	text = new FTextLog(pad, slider->h()+pad, window->w()-2*pad, window->h()-slider->h()-2*pad, 0);
+	text = new FTextView(pad, slider->h()+pad, window->w()-2*pad, window->h()-slider->h()-2*pad, 0);
 	text->textfont(FL_COURIER);
 	text->textsize(FL_NORMAL_SIZE);
+
 	window->resizable(text);
 	window->end();
 }
@@ -128,15 +136,38 @@ void debug::log(level_e level, const char* func, const char* srcf, int line, con
 		snprintf(fmt, sizeof(fmt), "%c: %s: %s\n", *prefix[level], func, format);
 	va_list args;
 	va_start(args, format);
-	vfprintf(wfile, fmt, args);
+	intptr_t nw = vfprintf(wfile, fmt, args);
 	va_end(args);
-	if (tty && level <= DEBUG_LEVEL && level > QUIET_LEVEL) {
+	if (tty) {
+		if (level <= DEBUG_LEVEL && level > QUIET_LEVEL) {
+			va_start(args, format);
+			vfprintf(stderr, fmt, args);
+			va_end(args);
+		}
+	}
+	else if (unlikely(want_popup && (level == ERROR_LEVEL || level == WARN_LEVEL))) {
+		// If the backends logged an error and our stderr is not a tty,
+		// alert the user and offer to show the log window.  We only do
+		// this once and thereafter assume that the user will keep the
+		// log window displayed to be notified of errors.  To keep the
+		// popup small, we set a maximum width and add a ("...")  if it
+		// must be truncated.
+		const char ellipsis[] = "...";
+		size_t len = 60;
+		char* msg = new char[len + sizeof(ellipsis)];
 		va_start(args, format);
-		vfprintf(stderr, fmt, args);
+		if ((size_t)vsnprintf(msg, len, fmt, args) >= len)
+			memcpy(msg + len - 1, ellipsis, sizeof(ellipsis));
 		va_end(args);
+		Fl::add_timeout(0.0, popup_message, msg);
+		want_popup = false;
 	}
 
-	Fl::add_timeout(0.0, sync_text, 0);
+#ifdef __MINGW32__
+	fflush(wfile);
+#endif
+
+	Fl::add_timeout(0.0, sync_text, (void*)nw);
 }
 
 void debug::elog(const char* func, const char* srcf, int line, const char* text)
@@ -151,16 +182,22 @@ void debug::show(void)
 
 static char buf[BUFSIZ+1];
 
-void debug::sync_text(void*)
+void debug::sync_text(void* arg)
 {
+	intptr_t toread = (intptr_t)arg;
+	size_t block = MIN((size_t)toread, sizeof(buf) - 1);
 	ssize_t n;
-	while ((n = read(rfd, buf, sizeof(buf) - 1)) > 0) {
-		buf[n] = '\0';
-		text->add(buf);
+
+	while (toread > 0) {
+		if ((n = read(rfd, buf, block)) <= 0)
+			break;
 		if (unlikely(++nlines > MAX_LINES)) {
 			text->clear();
 			nlines = 0;
 		}
+		buf[n] = '\0';
+		text->add(buf);
+		toread -= n;
 	}
 }
 
@@ -168,19 +205,20 @@ debug::debug(const char* filename)
 {
 	if ((wfile = fopen(filename, "w")) == NULL)
 		throw strerror(errno);
-	setlinebuf(wfile);
+	setvbuf(wfile, (char*)NULL, _IOLBF, 0);
 	set_cloexec(fileno(wfile), 1);
 
 	if ((rfile = fopen(filename, "r")) == NULL)
 		throw strerror(errno);
 	rfd = fileno(rfile);
 	set_cloexec(rfd, 1);
+#ifndef __MINGW32__
 	int f;
 	if ((f = fcntl(rfd, F_GETFL)) == -1)
 		throw strerror(errno);
 	if (fcntl(rfd, F_SETFL, f | O_NONBLOCK) == -1)
 		throw strerror(errno);
-
+#endif
 	tty = isatty(fileno(stderr));
 }
 
@@ -201,3 +239,18 @@ static void src_menu_cb(Fl_Widget* w, void*)
 {
 	debug::mask ^= 1 << ((Fl_Menu_*)w)->value();
 }
+
+static void popup_message(void* msg)
+{
+	if (!Fl::first_window() || !Fl::first_window()->visible()) // defer
+		return Fl::add_timeout(0.5, popup_message, msg);
+
+	if (fl_warn_choice2("%s:\n%s", _("Close"), _("View log"),
+			    NULL, _("A message was logged"), (char*)msg)) {
+		window->show();
+		text->insert_position(text->buffer()->length());
+		text->show_insert_position();
+	}
+
+	delete [] (char*)msg;
+}
