@@ -8,12 +8,14 @@
 #include <string>
 #include <list>
 #include <map>
+#include <tr1/unordered_map>
 #include <algorithm>
 
 #include "dxcc.h"
 #include "debug.h"
 
 using namespace std;
+using tr1::unordered_map;
 
 
 dxcc::dxcc(const char* cn, int cq, int itu, const char* ct, float lat, float lon, float tz)
@@ -26,24 +28,30 @@ dxcc::dxcc(const char* cn, int cq, int itu, const char* ct, float lat, float lon
 	continent[2] = '\0';
 }
 
-typedef map<string, dxcc*> dxcc_map;
-static dxcc_map* cmap = 0;
-static list<string>* cnames = 0;
+typedef unordered_map<string, dxcc*> dxcc_map_t;
+typedef vector<dxcc*> dxcc_list_t;
+static dxcc_map_t* cmap = 0;
+static dxcc_list_t* clist = 0;
+static vector<string>* cnames = 0;
 
 static void add_prefix(string& prefix, dxcc* entry);
 
 bool dxcc_open(const char* filename)
 {
-	dxcc_close();
+	if (cmap)
+		return true;
 
 	ifstream in(filename);
 	if (!in) {
-		LOG_WARN("Could not read contest country file \"%s\"", filename);
+		LOG_INFO("Could not read contest country file \"%s\"", filename);
 		return false;
 	}
 
-	cmap = new dxcc_map;
-	cnames = new list<string>;
+	cmap = new dxcc_map_t;
+	cnames = new vector<string>;
+	cnames->reserve(345); // approximate number of dxcc entities
+	clist = new dxcc_list_t;
+	clist->reserve(345);
 
 	dxcc* entry;
 	string record;
@@ -56,6 +64,7 @@ bool dxcc_open(const char* filename)
 
 		// read country name
 		cnames->resize(cnames->size() + 1);
+		clist->push_back(entry);
 		getline(is, cnames->back(), ':');
 		entry->country = cnames->back().c_str();
 		// cq zone
@@ -77,24 +86,26 @@ bool dxcc_open(const char* filename)
 		string prefix;
 		while ((c = is.peek()) == ' ' || c == '\r' || c == '\n') {
 			is >> ws;
-			if (is.peek() == '=')
-				is.ignore();
+
 			while (getline(is, prefix, ',')) {
 				add_prefix(prefix, entry);
 				if ((c = is.peek()) == '\r' || c == '\n')
 					break;
-				else if (c == '=')
-					is.ignore();
 			}
 		}
 
 		in >> ws; // cr/lf after ';'
 	}
 
-	LOG_INFO("Loaded %zu prefixes for %u countries", cmap->size(), nrec);
+	LOG_INFO("Loaded %" PRIuSZ " prefixes for %u countries", cmap->size(), nrec);
 	return true;
 }
 
+bool dxcc_is_open(void)
+{
+	return cmap;
+}
+
 void dxcc_close(void)
 {
 	if (!cmap)
@@ -102,11 +113,18 @@ void dxcc_close(void)
 	delete cnames;
 	cnames = 0;
 	map<dxcc*, bool> rm;
-	for (dxcc_map::iterator i = cmap->begin(); i != cmap->end(); ++i)
+	for (dxcc_map_t::iterator i = cmap->begin(); i != cmap->end(); ++i)
 		if (rm.insert(make_pair(i->second, true)).second)
 			delete i->second;
 	delete cmap;
 	cmap = 0;
+	delete clist;
+	clist = 0;
+}
+
+const vector<dxcc*>* dxcc_entity_list(void)
+{
+	return clist;
 }
 
 const dxcc* dxcc_lookup(const char* callsign)
@@ -115,10 +133,17 @@ const dxcc* dxcc_lookup(const char* callsign)
 		return NULL;
 
 	string sstr;
-	sstr.resize(strlen(callsign));
-	transform(callsign, callsign + sstr.length(), sstr.begin(), static_cast<int (*)(int)>(toupper));
+	sstr.resize(strlen(callsign) + 1);
+	transform(callsign, callsign + sstr.length() - 1, sstr.begin() + 1, static_cast<int (*)(int)>(toupper));
 
-	dxcc_map::const_iterator entry;
+	// first look for a full callsign (prefixed with '=')
+	sstr[0] = '=';
+	dxcc_map_t::const_iterator entry = cmap->find(sstr);
+	if (entry != cmap->end())
+		return entry->second;
+
+	// erase the '=' and do a longest prefix search
+	sstr.erase(0, 1);
 	size_t len = sstr.length();
 	do {
 		sstr.resize(len--);
@@ -131,11 +156,9 @@ const dxcc* dxcc_lookup(const char* callsign)
 
 static void add_prefix(string& prefix, dxcc* entry)
 {
-	static dxcc_map::iterator prev_entry = cmap->begin();
-
 	string::size_type i = prefix.find_first_of("([<{");
 	if (likely(i == string::npos)) {
-		prev_entry = cmap->insert(prev_entry, make_pair(prefix, entry));
+		(*cmap)[prefix] = entry;
 		return;
 	}
 
@@ -184,11 +207,12 @@ static void add_prefix(string& prefix, dxcc* entry)
 	} while ((i = prefix.find_first_of("([<{", j)) != string::npos);
 
 	prefix.erase(first);
-	prev_entry = cmap->insert(prev_entry, make_pair(prefix, entry));
+	(*cmap)[prefix] = entry;
 }
 
-typedef map<string, unsigned char> qsl_map;
-static qsl_map* qsl_calls;
+typedef unordered_map<string, unsigned char> qsl_map_t;
+static qsl_map_t* qsl_calls;
+static unsigned char qsl_open_;
 const char* qsl_names[] = { "LoTW", "eQSL" };
 
 bool qsl_open(const char* filename, qsl_t qsl_type)
@@ -197,30 +221,35 @@ bool qsl_open(const char* filename, qsl_t qsl_type)
 	if (!in)
 		return false;
 	if (!qsl_calls)
-		qsl_calls = new qsl_map;
+		qsl_calls = new qsl_map_t;
 
 	size_t n = qsl_calls->size();
-	qsl_map::iterator prev_entry = qsl_calls->begin();
 	string::size_type p;
 	string s;
 	s.reserve(32);
 	while (getline(in, s)) {
 		if ((p = s.rfind('\r')) != string::npos)
 			s.erase(p);
-		prev_entry = qsl_calls->insert(prev_entry, make_pair(s, 0));
-		prev_entry->second |= (1 << qsl_type);
+		(*qsl_calls)[s] |= (1 << qsl_type);
 	}
 
-	LOG_INFO("Added %zu %s callsigns from \"%s\"",
+	LOG_INFO("Added %" PRIuSZ " %s callsigns from \"%s\"",
 		 qsl_calls->size() - n, qsl_names[qsl_type], filename);
 
+	qsl_open_ |= (1 << qsl_type);
 	return true;
 }
 
+unsigned char qsl_is_open(void)
+{
+	return qsl_open_;
+}
+
 void qsl_close(void)
 {
 	delete qsl_calls;
 	qsl_calls = 0;
+	qsl_open_ = 0;
 }
 
 unsigned char qsl_lookup(const char* callsign)
@@ -232,6 +261,6 @@ unsigned char qsl_lookup(const char* callsign)
 	str.resize(strlen(callsign));
 	transform(callsign, callsign + str.length(), str.begin(), static_cast<int (*)(int)>(toupper));
 
-	qsl_map::const_iterator i = qsl_calls->find(str);
+	qsl_map_t::const_iterator i = qsl_calls->find(str);
 	return i == qsl_calls->end() ? 0 : i->second;
 }
