@@ -1,18 +1,25 @@
 #include <config.h>
 
-#include <glob.h>
+#include <string>
+#ifndef __MINGW32__
+#  include <glob.h>
+#endif
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
 #include <cstring>
 
+#include <FL/Fl_Pixmap.H>
+
 #include "macros.h"
 #include "macroedit.h"
 #include "globals.h"
 #include "status.h"
 #include "fileselect.h"
-
-#include <string>
+#include "fl_lock.h"
+#include "fl_digi.h"
+#include "main.h"
+#include "pixmaps.h"
 
 using namespace std;
 
@@ -23,11 +30,12 @@ Fl_Button	*btnMacroEditCancel = (Fl_Button *)0;
 Fl_Button	*btnInsertMacro = (Fl_Button *)0;
 Fl_Input2	*macrotext = (Fl_Input2 *)0;
 Fl_Input2	*labeltext = (Fl_Input2 *)0;
-static int widths[] = {90, 0};
+static int widths[] = {110, 0};
 
 Fl_Hold_Browser *macroDefs=(Fl_Hold_Browser *)0;
 
-static int iMacro;
+static int iMacro, iType;
+static Fl_Input* iInput;
 
 // fl_color(0) is always the foreground colour
 #define LINE_SEP "@B0"
@@ -37,20 +45,20 @@ void loadBrowser(Fl_Widget *widget) {
 	w->add("<MYCALL>\tmy call");
 	w->add("<MYLOC>\tmy locator");
 	w->add("<MYNAME>\tmy name");
-	w->add("<MYQTH>\tmy qth");
+	w->add("<MYQTH>\tmy QTH");
 	w->add("<MYRST>\tmy RST");
 
 	w->add(LINE_SEP);
 	w->add("<CALL>\tother call");
 	w->add("<LOC>\tother locator");
-	w->add("<NAME>\tremote name");
-	w->add("<QTH>\tother qth");
+	w->add("<NAME>\tother name");
+	w->add("<QTH>\tother QTH");
 	w->add("<RST>\tother RST");
-	w->add("<INFO1>\ts/n etc.");
-	w->add("<INFO2>\timd etc.");
+	w->add("<INFO1>\tS/N etc.");
+	w->add("<INFO2>\tIMD etc.");
 	
 	w->add(LINE_SEP);
-	w->add("<CLRRX>\tclear Rx pane");
+	w->add("<CLRRX>\tclear RX pane");
 	
 	w->add(LINE_SEP);
 	w->add("<GET>\ttext to NAME/QTH");
@@ -60,37 +68,41 @@ void loadBrowser(Fl_Widget *widget) {
 	w->add("<MODE>\tmode");
 
 	w->add(LINE_SEP);
-	w->add("<QSOTIME>\tqso time HHMM");
+	w->add("<QSOTIME>\tQSO time (HHMM)");
 	w->add("<LDT>\tLocal datetime");
 	w->add("<ILDT>\tLDT in iso-8601 format");
-	w->add("<ZDT>\tZulu datetime");
+	w->add("<ZDT>\tUTC datetime");
 	w->add("<IZDT>\tZDT in iso-8601 format");
 
 	w->add(LINE_SEP);
-	w->add("<CNTR>\tcontest cnt");
-	w->add("<DECR>\tdecr cnt");
-	w->add("<INCR>\tincr cnt");
-	w->add("<XOUT>\tExchange out");
+	w->add("<CNTR>\tcontest counter");
+	w->add("<DECR>\tdecrement counter");
+	w->add("<INCR>\tincrement counter");
+	w->add("<XOUT>\texchange out");
 
 	w->add(LINE_SEP);
-	w->add("<ID>\tMode ID'r");
-	w->add("<TEXT>\tVideo text");
+	w->add("<ID>\tmode ID");
+	w->add("<TEXT>\tvideo text");
 	w->add("<CWID>\tCW identifier");
 
 	w->add(LINE_SEP);
 	w->add("<RX>\treceive");
 	w->add("<TX>\ttransmit");
 	w->add("<LOG>\tsave QSO data");
-	w->add("<VER>\tFldigi + version");
+	w->add("<VER>\tFldigi version");
 	w->add("<TIMER:NN>\trepeat every NN sec");
 	w->add("<IDLE:NN>\tidle signal for NN sec");
 	
 	w->add(LINE_SEP);
-	w->add("<WPM:NN>\tCW wpm");
-	w->add("<RISE:nn.n>\tCW risetime");
+	w->add("<WPM:NN>\tCW WPM");
+	w->add("<RISE:nn.n>\tCW rise time");
 	w->add("<PRE:nn.n>\tQSK pre-timing");
 	w->add("<POST:+/-nn.n>\tQSK post-timing");
 	
+	w->add(LINE_SEP);
+	w->add("<AFC:on|off|t>\tAFC  on,off,toggle");
+	w->add("<RSID:on|off|t>\tRSID on,off,toggle");
+
 	w->add(LINE_SEP);
 	w->add("<FILE:>\tinsert text file");
 	w->add("<MACROS:>\tchange macro defs file");
@@ -102,6 +114,7 @@ void loadBrowser(Fl_Widget *widget) {
 		w->add(s);
 	}
 
+#ifndef __MINGW32__
 	glob_t gbuf;
 	glob(string(ScriptsDir).append("*").c_str(), 0, NULL, &gbuf);
 	if (gbuf.gl_pathc == 0) {
@@ -122,24 +135,26 @@ void loadBrowser(Fl_Widget *widget) {
 		}
 	}
 	globfree(&gbuf);
+#endif
 }
 
 void cbMacroEditOK(Fl_Widget *w, void *)
 {
-	macros.text[iMacro] = macrotext->value();
-	macros.name[iMacro] = labeltext->value();
-	FL_LOCK_D();
-		int n = iMacro;
-		while (n >= 12) n-= 12;
-//		if (n >= 12) n -= 12;
-		btnMacro[n]->label( macros.name[iMacro].c_str());
-	FL_UNLOCK_D();
-	MacroEditDialog->hide();
-	macros.changed = true;
-}
+	if (w == btnMacroEditCancel)
+		goto ret;
 
-void cbMacroEditCancel(Fl_Widget *w, void *)
-{
+	if (iType == MACRO_EDIT_BUTTON) {
+		macros.text[iMacro] = macrotext->value();
+		macros.name[iMacro] = labeltext->value();
+		int n = iMacro;
+		while (n >= 12)
+			n-= 12;
+		btnMacro[n]->label(macros.name[iMacro].c_str());
+		macros.changed = true;
+	}
+	else if (iType == MACRO_EDIT_INPUT)
+		iInput->value(macrotext->value());
+ret:
 	MacroEditDialog->hide();
 }
 
@@ -175,47 +190,55 @@ void cbInsertMacro(Fl_Widget *, void *)
 	macrotext->take_focus();
 }
 
-static string editor_label;
-
 Fl_Double_Window* make_macroeditor(void)
 {
-	editor_label.append("Macro editor - ").append(progStatus.LastMacroFile);
+	Fl_Double_Window* w = new Fl_Double_Window(730, 230, "");
+	labeltext = new Fl_Input2(45, 15, 115, 25, "Label:");
+	labeltext->textfont(FL_COURIER);
 
-	Fl_Double_Window* w = new Fl_Double_Window(700, 230, editor_label.c_str());
-		labeltext = new Fl_Input2(114, 15, 95, 25, "Label:");
-		
-		btnMacroEditOK = new Fl_Button(500, 15, 75, 25, "OK");
-		btnMacroEditOK->callback(cbMacroEditOK);
-		
-		btnMacroEditCancel = new Fl_Button(600, 15, 75, 25, "Cancel");
-		btnMacroEditCancel->callback(cbMacroEditCancel);
-		
-		macrotext = new Fl_Input2(5, 60, 450, 165, "Text");
-		macrotext->type(4);
-		macrotext->align(FL_ALIGN_TOP_LEFT);
-		
-		btnInsertMacro = new Fl_Button(460, 114, 25, 25, "@<<");
-		btnInsertMacro->callback(cbInsertMacro);
-		
-		macroDefs = new Fl_Hold_Browser(490, 60, 200, 165);
-		macroDefs->column_widths(widths);
-		loadBrowser(macroDefs);
+	btnMacroEditOK = new Fl_Button(500, 15, 75, 25, "OK");
+	btnMacroEditOK->callback(cbMacroEditOK);
+
+	btnMacroEditCancel = new Fl_Button(600, 15, 75, 25, "Cancel");
+	btnMacroEditCancel->callback(cbMacroEditOK);
+
+	macrotext = new Fl_Input2(5, 60, 450, 165, "Text:");
+	macrotext->type(FL_MULTILINE_INPUT);
+	macrotext->textfont(FL_COURIER);
+	macrotext->align(FL_ALIGN_TOP_LEFT);
+
+	btnInsertMacro = new Fl_Button(460, 125, 25, 25);
+	btnInsertMacro->image(new Fl_Pixmap(left_arrow_icon));
+	btnInsertMacro->callback(cbInsertMacro);
+
+	macroDefs = new Fl_Hold_Browser(490, 60, 235, 165);
+	macroDefs->column_widths(widths);
+	loadBrowser(macroDefs);
 	w->end();
+	w->xclass(PACKAGE_NAME);
 	return w;
 }
 
-void editMacro(int n)
+void editMacro(int n, int t, Fl_Input* in)
 {
-	if (!MacroEditDialog) MacroEditDialog = make_macroeditor();
-	else {
-		editor_label = "";
+	if (!MacroEditDialog)
+		MacroEditDialog = make_macroeditor();
+	if (t == MACRO_EDIT_BUTTON) {
+		string editor_label;
 		editor_label.append("Macro editor - ").append(progStatus.LastMacroFile);
-		MacroEditDialog->label(editor_label.c_str());
+		if (editor_label != MacroEditDialog->label())
+			MacroEditDialog->copy_label(editor_label.c_str());
+		macrotext->value(macros.text[n].c_str());
+		labeltext->value(macros.name[n].c_str());
+		labeltext->show();
+	}
+	else if (t == MACRO_EDIT_INPUT) {
+		MacroEditDialog->label(in->label());
+		macrotext->value(in->value());
+		labeltext->hide();
 	}
-	macrotext->value(macros.text[n].c_str());
-	labeltext->value(macros.name[n].c_str());
 	iMacro = n;
-	MacroEditDialog->xclass(PACKAGE_NAME);
+	iType = t;
+	iInput = in;
 	MacroEditDialog->show();
 }
-
