@@ -12,8 +12,11 @@
 #include "globals.h"
 #include "debug.h"
 #include "status.h"
+#include "trx.h"
+#include "modem.h"
 
 #include <FL/Fl.H>
+#include <FL/filename.H>
 #include "fileselect.h"
 
 #include <ctime>
@@ -23,6 +26,8 @@
 #include <string>
 #include <fstream>
 
+using namespace std;
+
 MACROTEXT macros;
 CONTESTCNTR contest_count;
 static bool TransmitON = false;
@@ -73,6 +78,8 @@ void pWPM(string &, size_t &);
 void pRISETIME(string &, size_t &);
 void pPRE(string &, size_t &);
 void pPOST(string &, size_t &);
+void pAFC(string &, size_t &);
+void pRSID(string &, size_t &);
 //void pMACROS(string &, size_t &);
 
 MTAGS mtags[] = {
@@ -120,6 +127,8 @@ MTAGS mtags[] = {
 {"<RISE:",      pRISETIME},
 {"<PRE:",       pPRE},
 {"<POST:",      pPOST},
+{"<AFC:",       pAFC},
+{"<RSID:",      pRSID},
 //{"<MACROS:",	pMACROS},
 {0, 0}
 };
@@ -130,6 +139,21 @@ static bool GET = false;
 string info1msg = "";
 string info2msg = "";
 
+static char cutnumbers[] = "T12345678N";
+static string cutstr;
+
+string cutstring(const char *s)
+{
+	cutstr = s;
+	if (!progdefaults.cutnbrs || active_modem != cw_modem)
+		return cutstr;
+
+	for (size_t i = 0; i < cutstr.length(); i++)
+		if (cutstr[i] >= '0' && cutstr[i] <= '9')
+			cutstr[i] = cutnumbers[cutstr[i] - '0'];
+	return cutstr;
+}
+
 size_t mystrftime( char *s, size_t max, const char *fmt, const struct tm *tm) {
 	return strftime(s, max, fmt, tm);
 }
@@ -159,12 +183,10 @@ void pTIMER(string &s, size_t &i)
 	string sTime = s.substr(i+7, endbracket - i - 7);
 	if (sTime.length() > 0) {
 		sscanf(sTime.c_str(), "%d", &number);
-		s.replace(i, endbracket - i + 1, "");
-		progdefaults.timeout = number;
-		progdefaults.macronumber = mNbr;
-		progdefaults.useTimer = true;
-	} else
-		s.replace(i, endbracket - i + 1, "");
+		progStatus.timer = number;
+		progStatus.timerMacro = mNbr;
+	}
+	s.replace(i, endbracket - i + 1, "");
 }
 
 void pWPM(string &s, size_t &i)
@@ -176,11 +198,10 @@ void pWPM(string &s, size_t &i)
 		sscanf(sTime.c_str(), "%d", &number);
 		if (number < 5) number = 5;
 		if (number > 200) number = 200;
-		s.replace(i, endbracket - i + 1, "");
 		progdefaults.CWspeed = number;
-        sldrCWxmtWPM->value(number);
-	} else
-		s.replace(i, endbracket - i + 1, "");
+		sldrCWxmtWPM->value(number);
+	}
+	s.replace(i, endbracket - i + 1, "");
 }
 
 void pRISETIME(string &s, size_t &i)
@@ -192,11 +213,10 @@ void pRISETIME(string &s, size_t &i)
 		sscanf(sVal.c_str(), "%f", &number);
 		if (number < 0) number = 0;
 		if (number > 20) number = 20;
-		s.replace(i, endbracket - i + 1, "");
 		progdefaults.CWrisetime = number;
-    	cntCWrisetime->value(number);
-	} else
-		s.replace(i, endbracket - i + 1, "");
+		cntCWrisetime->value(number);
+	}
+	s.replace(i, endbracket - i + 1, "");
 }
 
 void pPRE(string &s, size_t &i)
@@ -208,11 +228,10 @@ void pPRE(string &s, size_t &i)
 		sscanf(sVal.c_str(), "%f", &number);
 		if (number < 0) number = 0;
 		if (number > 20) number = 20;
-		s.replace(i, endbracket - i + 1, "");
 		progdefaults.CWpre = number;
 		cntPreTiming->value(number);
-	} else
-		s.replace(i, endbracket - i + 1, "");
+	}
+	s.replace(i, endbracket - i + 1, "");
 }
 
 void pPOST(string &s, size_t &i)
@@ -222,13 +241,12 @@ void pPOST(string &s, size_t &i)
 	string sVal = s.substr(i+6, endbracket - i - 6);
 	if (sVal.length() > 0) {
 		sscanf(sVal.c_str(), "%f", &number);
-		s.replace(i, endbracket - i + 1, "");
 		if (number < -20) number = -20;
 		if (number > 20) number = 20;
 		progdefaults.CWpost = number;
 		cntPostTiming->value(number);
-	} else
-		s.replace(i, endbracket - i + 1, "");
+	}
+	s.replace(i, endbracket - i + 1, "");
 }
 
 bool useIdle = false;
@@ -241,11 +259,10 @@ void pIDLE(string &s, size_t &i)
 	string sTime = s.substr(i+6, endbracket - i - 6);
 	if (sTime.length() > 0) {
 		sscanf(sTime.c_str(), "%d", &number);
-		s.replace(i, endbracket - i + 1, "");
 		useIdle = true;
 		idleTime = number;
-	} else
-		s.replace(i, endbracket - i + 1, "");
+	}
+	s.replace(i, endbracket - i + 1, "");
 }
 
 
@@ -308,7 +325,7 @@ void pQSOTIME(string &s, size_t &i)
 
 void pRST(string &s, size_t &i)
 {
-	s.replace( i, 5, inpRstOut->value() );
+	s.replace( i, 5, cutstring(inpRstOut->value()));
 }
 
 void pMYCALL(string &s, size_t &i)
@@ -424,7 +441,7 @@ void pCNTR(string &s, size_t &i)
 	if (contestval) {
 		contest_count.Format(progdefaults.ContestDigits, progdefaults.UseLeadingZeros);
 		snprintf(contest_count.szCount, sizeof(contest_count.szCount), contest_count.fmt.c_str(), contestval);
-		s.replace (i, 6, contest_count.szCount);
+		s.replace (i, 6, cutstring(contest_count.szCount));
 	} else
 		s.replace (i, 6, "");
 }
@@ -450,7 +467,7 @@ void pINCR(string &s, size_t &i)
 
 void pXOUT(string &s, size_t &i)
 {
-	s.replace (i, 6, progdefaults.myXchg);
+	s.replace( i, 6, cutstring(progdefaults.myXchg.c_str()));
 }
 
 void pLOG(string &s, size_t &i)
@@ -485,10 +502,52 @@ void pMODEM(string &s, size_t &i)
 	s.erase(i, k-i);
 }
 
-void set_env(void)
+void pAFC(string &s, size_t &i)
 {
-	enum { PATH, FLDIGI_RX_IPC_KEY, FLDIGI_TX_IPC_KEY, FLDIGI_VERSION,
-	       FLDIGI_PID, FLDIGI_CONFIG_DIR,
+  size_t endbracket = s.find('>',i);
+  string sVal = s.substr(i+5, endbracket - i - 5);
+  if (sVal.length() > 0) {
+    // sVal = on|off|t   [ON, OFF or Toggle]
+    if (sVal.compare(0,2,"on") == 0)
+      btnAFC->value(1);
+    else if (sVal.compare(0,3,"off") == 0)
+      btnAFC->value(0);
+    else if (sVal.compare(0,1,"t") == 0)
+      btnAFC->value(!btnAFC->value());
+
+    btnAFC->do_callback();
+  }
+  s.replace(i, endbracket - i + 1, "");
+}
+
+void pRSID(string &s, size_t &i)
+{
+  size_t endbracket = s.find('>',i);
+  string sVal = s.substr(i+6, endbracket - i - 6);
+  if (sVal.length() > 0) {
+    // sVal = on|off|t   [ON, OFF or Toggle]
+    if (sVal.compare(0,2,"on") == 0)
+      btnRSID->value(1);
+    else if (sVal.compare(0,3,"off") == 0)
+      btnRSID->value(0);
+    else if (sVal.compare(0,1,"t") == 0)
+      btnRSID->value(!btnRSID->value());
+
+    btnRSID->do_callback();
+  }
+  s.replace(i, endbracket - i + 1, "");
+}
+
+void set_macro_env(void)
+{
+	enum {
+#ifndef __WOE32__
+	       PATH, FLDIGI_RX_IPC_KEY, FLDIGI_TX_IPC_KEY,
+#endif
+	       FLDIGI_XMLRPC_ADDRESS, FLDIGI_XMLRPC_PORT,
+	       FLDIGI_ARQ_ADDRESS, FLDIGI_ARQ_PORT,
+
+	       FLDIGI_VERSION_ENVVAR, FLDIGI_PID, FLDIGI_CONFIG_DIR,
 
 	       FLDIGI_MY_CALL, FLDIGI_MY_NAME, FLDIGI_MY_LOCATOR,
 
@@ -504,9 +563,16 @@ void set_env(void)
 		const char* var;
 		const char* val;
 	} env[] = {
+#ifndef __WOE32__
 		{ "PATH", "" },
 		{ "FLDIGI_RX_IPC_KEY", "" },
 		{ "FLDIGI_TX_IPC_KEY", "" },
+#endif
+		{ "FLDIGI_XMLRPC_ADDRESS", progdefaults.xmlrpc_address.c_str() },
+		{ "FLDIGI_XMLRPC_PORT", progdefaults.xmlrpc_port.c_str() },
+		{ "FLDIGI_ARQ_ADDRESS", progdefaults.arq_address.c_str() },
+		{ "FLDIGI_ARQ_PORT", progdefaults.arq_port.c_str() },
+
 		{ "FLDIGI_VERSION", PACKAGE_VERSION },
 		{ "FLDIGI_PID", "" },
 		{ "FLDIGI_CONFIG_DIR", HomeDir.c_str() },
@@ -535,6 +601,7 @@ void set_env(void)
 		{ "FLDIGI_AZ", inpAZ->value() }
 	};
 
+#ifndef __WOE32__
 	// PATH
 	static string path = ScriptsDir;
 	path.erase(path.length()-1,1);
@@ -549,6 +616,7 @@ void set_env(void)
 	env[FLDIGI_RX_IPC_KEY].val = key[0];
 	snprintf(key[1], sizeof(key[1]), "%d", progdefaults.tx_msgid);
 	env[FLDIGI_TX_IPC_KEY].val = key[1];
+#endif
 
 	// pid
 	char pid[6];
@@ -569,7 +637,7 @@ void set_env(void)
 	env[FLDIGI_FREQUENCY].val = freq;
 
 	// debugging vars
-#ifndef NDEBUG
+#if !defined(NDEBUG) && !defined(__WOE32__)
 	unsetenv("FLDIGI_NO_EXEC");
 	unsetenv("MALLOC_CHECK_");
 	unsetenv("MALLOC_PERTURB_");
@@ -579,6 +647,7 @@ void set_env(void)
 		setenv(env[j].var, env[j].val, 1);
 }
 
+#ifndef __MINGW32__
 void pEXEC(string &s, size_t &i)
 {
 	size_t start, end;
@@ -607,9 +676,9 @@ void pEXEC(string &s, size_t &i)
 			exit(EXIT_FAILURE);
 		}
 		close(pfd[1]);
-		set_env();
+		set_macro_env();
 		execl("/bin/sh", "sh", "-c", s.substr(start, end-start).c_str(), (char *)NULL);
-		LOG_PERROR("execl");
+		perror("execl");
 		exit(EXIT_FAILURE);
 	}
 	// parent
@@ -642,6 +711,15 @@ void pEXEC(string &s, size_t &i)
 	// i = start;
 	// option 2: do nothing and allow it to be parsed for more macros
 }
+#else // !__MINGW32__
+void pEXEC(string& s, size_t& i)
+{
+	size_t end = s.find("</EXEC>", i);
+	if (end != string::npos)
+		s.erase(i, end + strlen("</EXEC>") - i);
+	LOG_WARN("Ignoring unimplemented EXEC macro");
+}
+#endif // !__MINGW32__
 
 void pSTOP(string &s, size_t &i)
 {
@@ -655,7 +733,7 @@ void pCONT(string &s, size_t &i)
 	expand = true;
 }
 
-int MACROTEXT::loadMacros(string filename)
+int MACROTEXT::loadMacros(const string& filename)
 {
 	string mLine;
 	string mName;
@@ -736,7 +814,7 @@ void MACROTEXT::loadDefault()
 		progStatus.LastMacroFile = "macros.mdf";
 	}
 	if ((erc = loadMacros(Filename)) != 0)
-#ifndef __CYGWIN__
+#ifndef __WOE32__
 		LOG_ERROR("Error #%d loading %s\n", erc, Filename.c_str());
 #else
 	;
@@ -883,7 +961,7 @@ string mtext =
 //\n\
 ";
 
-void MACROTEXT::saveMacros(string fname) {
+void MACROTEXT::saveMacros(const string& fname) {
 	string work;
 	ofstream mfile(fname.c_str());
 	mfile << mtext;
