@@ -106,8 +106,7 @@ unsigned char rbits8(unsigned char w)
 
 // Integer base-2 logarithm
 
-#ifndef __CYGWIN__
-unsigned int log2(unsigned int x)
+unsigned int log2u(unsigned int x)
 {
 	int y = 0;
 	x >>= 1;
@@ -117,7 +116,6 @@ unsigned int log2(unsigned int x)
 	}
 	return y;
 }
-#endif
 
 // ----------------------------------------------------------------------------
 
@@ -147,12 +145,6 @@ unsigned char graydecode(unsigned char data)
 
 // ----------------------------------------------------------------------------
 
-void MilliSleep(long msecs)
-{
-	struct timespec tv = {0, msecs * 1000000L};
-	nanosleep(&tv, NULL);
-}
-
 // Rectangular - no pre filtering of data array
 void RectWindow(double *array, int n) {
 	for (int i = 0; i < n; i++)
