@@ -23,13 +23,18 @@
 #include <config.h>
 
 #include <sys/types.h>
-#include <sys/socket.h>
-#include <netdb.h>
-#include <arpa/inet.h>
-#include <netinet/in.h>
-#include <netinet/tcp.h>
-#include <sys/time.h>
-#include <sys/select.h>
+
+#ifndef __MINGW32__
+#  include <sys/socket.h>
+#  include <netdb.h>
+#  include <arpa/inet.h>
+#  include <netinet/in.h>
+#  include <sys/time.h>
+#  include <sys/select.h>
+#else
+#  include "compat.h"
+#endif
+
 #include <unistd.h>
 #include <fcntl.h>
 
@@ -432,10 +437,15 @@ Socket::Socket(int fd)
 	if (sockfd == -1)
 		return;
 
+#ifndef __MINGW32__
 	int r = fcntl(sockfd, F_GETFL);
 	if (r == -1)
 		throw SocketException(errno, "fcntl");
 	nonblocking = r & O_NONBLOCK;
+#else
+	// no way to retrieve nonblocking status on woe32(?!)
+	set_nonblocking(false);
+#endif
 	autoclose = true;
 }
 
@@ -523,7 +533,7 @@ bool Socket::wait(int dir)
 {
 	fd_set fdset;
 	FD_ZERO(&fdset);
-	FD_SET(sockfd, &fdset);
+	FD_SET((unsigned)sockfd, &fdset);
 	struct timeval t = { timeout.tv_sec, timeout.tv_usec };
 
 	int r;
@@ -546,7 +556,7 @@ bool Socket::wait(int dir)
 void Socket::bind(void)
 {
 	int r = 1;
-	if (setsockopt(sockfd, SOL_SOCKET, SO_REUSEADDR, &r, sizeof(r)) == -1)
+	if (setsockopt(sockfd, SOL_SOCKET, SO_REUSEADDR, (const char*)&r, sizeof(r)) == -1)
 #ifndef NDEBUG
 		perror("setsockopt SO_REUSEADDR");
 #else
@@ -652,7 +662,7 @@ size_t Socket::send(const void* buf, size_t len)
 		if (!wait(1))
 			return 0;
 
-	ssize_t r = ::send(sockfd, buf, len, 0);
+	ssize_t r = ::send(sockfd, (const char*)buf, len, 0);
 	if (r == 0)
 		shutdown(sockfd, SHUT_WR);
 	else if (r == -1) {
@@ -693,7 +703,7 @@ size_t Socket::recv(void* buf, size_t len)
 		if (!wait(0))
 			return 0;
 
-	ssize_t r = ::recv(sockfd, buf, len, 0);
+	ssize_t r = ::recv(sockfd, (char*)buf, len, 0);
 	if (r == 0)
 		shutdown(sockfd, SHUT_RD);
 	else if (r == -1) {
@@ -725,6 +735,31 @@ size_t Socket::recv(string& buf)
 	return n;
 }
 
+///
+/// Retrieves the socket's receive or send buffer size
+///
+/// @param dir Specifies the I/O direction. 0 is input, 1 is output.
+///
+int Socket::get_bufsize(int dir)
+{
+	int len;
+	if (::get_bufsize(sockfd, dir, &len) == -1)
+		throw SocketException(errno, "get_bufsize");
+	return len;
+}
+
+///
+/// Sets the socket's receive or send buffer size
+///
+/// @param dir Specifies the I/O direction. 0 is input, 1 is output.
+/// @param len Specifies the new buffer size
+///
+void Socket::set_bufsize(int dir, int len)
+{
+	if (::set_bufsize(sockfd, dir, len) == -1)
+		throw SocketException(errno, "set_bufsize");
+}
+
 ///
 /// Sets the socket's blocking mode
 ///
@@ -732,15 +767,8 @@ size_t Socket::recv(string& buf)
 ///
 void Socket::set_nonblocking(bool v)
 {
-	int r;
-	if ((r = fcntl(sockfd, F_GETFL)) == -1)
-		throw SocketException(errno, "fcntl");
-	if (v)
-		r |= O_NONBLOCK;
-	else
-		r &= ~O_NONBLOCK;
-	if (fcntl(sockfd, F_SETFL, r) == -1)
-		throw SocketException(errno, "fcntl");
+	if (set_nonblock(sockfd, v) == -1)
+		throw SocketException(errno, "set_nonblock");
 	nonblocking = v;
 }
 
@@ -751,9 +779,8 @@ void Socket::set_nonblocking(bool v)
 ///
 void Socket::set_nodelay(bool v)
 {
-	int val = v;
-	if (setsockopt(sockfd, IPPROTO_TCP, TCP_NODELAY, &val, sizeof(val)) == -1)
-		throw SocketException(errno, "setsockopt");
+	if (::set_nodelay(sockfd, v) == -1)
+		throw SocketException(errno, "set_nodelay");
 }
 
 ///
