@@ -64,3 +64,16 @@ bool thread_in_list(int id, const int* list)
 	return false;
 }
 #endif
+
+#ifdef __linux__
+#  ifndef _GNU_SOURCE
+#    define _GNU_SOURCE
+#  endif
+#  include <unistd.h>
+#  include <sys/syscall.h>
+#  include "debug.h"
+void linux_log_tid(void)
+{
+	LOG_DEBUG(PACKAGE_TARNAME " thread %" PRIdPTR " is LWP %ld", GET_THREAD_ID(), syscall(SYS_gettid));
+}
+#endif
