@@ -28,14 +28,17 @@
 #include <config.h>
 
 #include <FL/Fl.H>
-#include <FL/fl_ask.H>
 
 #include "olivia.h"
-#include "sound.h"
+#include "modem.h"
+#include "fl_digi.h"
 
+#include "misc.h"
 #include "confdialog.h"
-
 #include "status.h"
+#include "debug.h"
+
+LOG_FILE_SOURCE(debug::LOG_MODEM);
 
 using namespace std;
 
@@ -311,7 +314,7 @@ void olivia::restart()
 	}
 
 	if (Tx->Preset() < 0) {
-		fl_message("olivia: transmitter preset failed!");
+		LOG_ERROR("olivia: transmitter preset failed!");
 		return;
 	}
 		
@@ -338,13 +341,13 @@ void olivia::restart()
 	}
 
 	if (Rx->Preset() < 0) {
-		fl_message("olivia: receiver preset failed!");
+		LOG_ERROR("olivia: receiver preset failed!");
 		return;
 	}
 	fragmentsize = 1024;
 	set_bandwidth(Tx->Bandwidth - Tx->Bandwidth / Tx->Tones);
 
-	put_MODEstatus("%s %zu/%zu", get_mode_name(), Tx->Tones, Tx->Bandwidth);
+	put_MODEstatus("%s %" PRIuSZ "/%" PRIuSZ "", get_mode_name(), Tx->Tones, Tx->Bandwidth);
 	metric = 0;
 }
 
