@@ -33,6 +33,10 @@
 #include <iomanip>
 
 #include "psk.h"
+#include "main.h"
+#include "fl_digi.h"
+#include "trx.h"
+#include "misc.h"
 #include "waterfall.h"
 #include "configuration.h"
 #include "status.h"
@@ -41,13 +45,6 @@
 
 extern waterfall *wf;
 
-//=====================================================================
-// Change the following constant to adjust the # of DCD symbols 
-// sent at the end of every transmission.  The DCD symbol is 0x02.
-// 32 is the # used in gMFSK and earlier versions of fldigi
-
-#define DCDOFF  32
-
 // Change the following for DCD low pass filter adjustment
 #define SQLCOEFF 0.01
 #define SQLDECAY 50
@@ -311,7 +308,7 @@ void psk::searchDown()
 	while (srchfreq > minfreq) {
 		spwr = wf->powerDensity(srchfreq, bandwidth);
 		npwr = wf->powerDensity(srchfreq + bandwidth, bandwidth/2) + 1e-10;
-		if (spwr / npwr > SNTHRESHOLD) {
+		if (spwr / npwr > pow(10, progdefaults.ServerACQsn / 10)) {
 			frequency = srchfreq;
 			set_freq(frequency);
 			sigsearch = SIGSEARCH;
@@ -329,7 +326,7 @@ void psk::searchUp()
 	while (srchfreq < maxfreq) {
 		spwr = wf->powerDensity(srchfreq, bandwidth/2);
 		npwr = wf->powerDensity(srchfreq - bandwidth, bandwidth/2) + 1e-10;
-		if (spwr / npwr > SNTHRESHOLD) {
+		if (spwr / npwr > pow(10, progdefaults.ServerACQsn / 10)) {
 			frequency = srchfreq;
 			set_freq(frequency);
 			sigsearch = SIGSEARCH;
@@ -348,16 +345,21 @@ void psk::findsignal()
 	if (sigsearch > 0) {
 		sigsearch--;
 		if (mailserver) { // mail server search algorithm
-			f1 = (int)(frequency - progdefaults.ServerOffset);
-			f2 = (int)(frequency + progdefaults.ServerOffset);
-			if (evalpsk->sigpeak(ftest, f1, f2) > SNTHRESHOLD ) {
+			if (progdefaults.PSKmailSweetSpot) {
+				f1 = (int)(progdefaults.ServerCarrier - progdefaults.ServerOffset);
+				f2 = (int)(progdefaults.ServerCarrier + progdefaults.ServerOffset);
+			} else {
+				f1 = (int)(frequency - progdefaults.ServerOffset);
+				f2 = (int)(frequency + progdefaults.ServerOffset);
+			}
+			if (evalpsk->sigpeak(ftest, f1, f2) > pow(10, progdefaults.ServerACQsn / 10) ) {
 				if (progdefaults.PSKmailSweetSpot) {
-					if (fabs(ftest - progdefaults.PSKsweetspot) < progdefaults.ServerOffset) {
+					if (fabs(ftest - progdefaults.ServerCarrier) < progdefaults.ServerOffset) {
 						frequency = ftest;
 						set_freq(frequency);
 						freqerr = 0.0;
 					} else {
-						frequency = progdefaults.PSKsweetspot;
+						frequency = progdefaults.ServerCarrier;
 						set_freq(frequency);
 						freqerr = 0.0;
 					}
@@ -368,7 +370,7 @@ void psk::findsignal()
 				}
 			} else { // less than the detection threshold
 				if (progdefaults.PSKmailSweetSpot) {
-					frequency = progdefaults.PSKsweetspot;
+					frequency = progdefaults.ServerCarrier;
 					set_freq(frequency);
 					sigsearch = SIGSEARCH;
 				}
@@ -381,7 +383,7 @@ void psk::findsignal()
 				set_freq(frequency);
 				freqerr = 0.0;
 				sigsearch = 0;
-				acquire = DCDOFF;
+				acquire = dcdbits;
 			}
 		}
 	}
@@ -393,14 +395,17 @@ void psk::phaseafc()
 	if (afcmetric < 0.05) return;
 	
 	error = (phase - bits * M_PI / 2.0);
-	if (error < -M_PI/2.0)
-		error += TWOPI;
-	if (error > M_PI/2.0)
-		error -= TWOPI;
-	error *= ((samplerate / TWOPI) / (16.0 * symbollen));
-	if (fabs(error) < bandwidth) {
-		freqerr = decayavg( freqerr, error, AFCDECAYSLOW);
+	if (error < -M_PI / 2.0 || error > M_PI / 2.0) return;
+	error *= samplerate / (TWOPI * symbollen);
+	if (fabs(error) < bandwidth ) {
+		freqerr = error / dcdbits;
 		frequency -= freqerr;
+		if (mailserver) {
+			if (frequency < progdefaults.ServerCarrier - progdefaults.ServerAFCrange)
+				frequency = progdefaults.ServerCarrier - progdefaults.ServerAFCrange;
+			if (frequency > progdefaults.ServerCarrier + progdefaults.ServerAFCrange)
+				frequency = progdefaults.ServerCarrier + progdefaults.ServerAFCrange;
+		}
 		set_freq (frequency);
 	}
 	if (acquire) acquire--;
@@ -675,7 +680,7 @@ void psk::tx_flush()
 	}
 
 // DCD off sequence (unmodulated carrier)
-	for (int i = 0; i < DCDOFF; i++)
+	for (int i = 0; i < dcdbits; i++)
 		tx_symbol(2);
 }
 
