@@ -24,6 +24,7 @@
 
 #include <config.h>
 
+#include <FL/Fl.H>
 #include <FL/Fl_Float_Input.H>
 #include <FL/fl_draw.H>
 #include <FL/Fl_Box.H>
@@ -217,13 +218,32 @@ void cFreqControl::value(long lv)
 	REQ(&cFreqControl::updatevalue, this);
 }
 
+void cFreqControl::cancel_kb_entry(void)
+{
+	Fl::remove_timeout((Fl_Timeout_Handler)blink_point, decbx);
+	val = oldval;
+	updatevalue();
+}
+
 int cFreqControl::handle(int event)
 {
-	if (!Fl::event_inside(this))
+	if (!Fl::event_inside(this) && event != FL_LEAVE)
 		return Fl_Group::handle(event);
 
+	static Fl_Widget* fw = NULL;
 	int d;
+
 	switch (event) {
+	case FL_ENTER:
+		fw = Fl::focus();
+		take_focus();
+		break;
+	case FL_LEAVE:
+		if (fw)
+			fw->take_focus();
+		if (Fl::has_timeout((Fl_Timeout_Handler)blink_point, decbx))
+			cancel_kb_entry();
+		break;
 	case FL_KEYBOARD:
 		switch (d = Fl::event_key()) {
 		case FL_Left:
@@ -247,9 +267,7 @@ int cFreqControl::handle(int event)
 		default:
 			if (Fl::has_timeout((Fl_Timeout_Handler)blink_point, decbx)) {
 				if (d == FL_Escape) {
-					Fl::remove_timeout((Fl_Timeout_Handler)blink_point, decbx);
-					val = oldval;
-					updatevalue();
+					cancel_kb_entry();
 					return 1;
 				}
 				else if (d == FL_Enter || d == FL_KP_Enter) { // append
@@ -284,7 +302,17 @@ int cFreqControl::handle(int event)
 		}
 		break;
 	case FL_PUSH:
-		return Fl_Group::handle(event);
+		if (Fl::event_button() == FL_MIDDLE_MOUSE)
+			Fl::paste(*this, 0);
+		else
+			return Fl_Group::handle(event);
+		break;
+	case FL_PASTE:
+		finp->value(Fl::event_text());
+		finp->position(finp->size());
+		finp->insert(" \n", 2); // space before newline for pasted text
+		finp->do_callback();
+		break;
 	}
 
 	return 1;
@@ -294,6 +322,8 @@ void cFreqControl::freq_input_cb(Fl_Widget*, void* arg)
 {
 	cFreqControl* fc = reinterpret_cast<cFreqControl*>(arg);
 	double val = strtod(fc->finp->value(), NULL);
+	if (val == 0.0 && fc->finp->index(fc->finp->size() - 2) == ' ')
+		return; // invalid pasted text
 	if (val >= 0.0 && val < pow(10.0, MAX_DIGITS - 3)) {
 		val *= 1e3;
 		val += 0.5;
