@@ -2,18 +2,14 @@
 // hamlib.cxx  --  Hamlib (rig control) interface for fldigi
 #include <config.h>
 
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#include <sys/ioctl.h>
-#include <termios.h>
 #include <cstdlib>
 #include <string>
 #include <vector>
+#include <algorithm>
 
+#include "trx.h"
 #include "configuration.h"
 #include "confdialog.h"
-#include <FL/fl_ask.H>
 
 #include "rigclass.h"
 
@@ -28,13 +24,13 @@
 #include "rigdialog.h"
 
 #include "stacktrace.h"
-#ifdef CYGWIN
+#ifdef __WOE32__
 #  include "serial.h"
 #endif
 #include "debug.h"
 #include "re.h"
 
-LOG_SET_SOURCE(debug::LOG_RIGCONTROL);
+LOG_FILE_SOURCE(debug::LOG_RIGCONTROL);
 
 using namespace std;
 
@@ -140,7 +136,7 @@ bool hamlib_init(bool bPtt)
 
 #ifdef __CYGWIN__
 	string port = progdefaults.HamRigDevice;
-	adjust_port(port);
+	com_to_tty(port);
 #endif
 
 	if (progdefaults.HamRigModel == 0) {
@@ -213,7 +209,7 @@ bool hamlib_init(bool bPtt)
 		return false;
 	}
 
-	MilliSleep(200);
+	MilliSleep(500);
 
 	try {
 		need_freq = true;
@@ -286,7 +282,7 @@ void hamlib_close(void)
 	while (!hamlib_closed) {
 		MilliSleep(50);
 		if (!count--) {
-			show_error(__func__, "Hamlib stuck, transceiver on fire");
+			show_error(__func__, "Hamlib thread not responding, forcing shutdown");
 			xcvr->close();
 			diediedie();
 		}
@@ -296,7 +292,7 @@ void hamlib_close(void)
 	if (rigcontrol)
 		rigcontrol->hide();
 	wf->USB(true);
-	wf->setQSY(0);
+//	wf->setQSY(0);
 }
 
 bool hamlib_active(void)
