@@ -33,15 +33,22 @@
 
 #include <unistd.h>
 #include <sys/types.h>
-#include <sys/select.h>
+#if HAVE_SYS_SELECT_H
+#  include <sys/select.h>
+#endif
 #include <sys/stat.h>
 #include <fcntl.h>
-#include <sys/ioctl.h>
-#include <termios.h>
+#if HAVE_SYS_IOCTL_H
+#  include <sys/ioctl.h>
+#endif
+#if HAVE_TERMIOS_H
+#  include <termios.h>
+#endif
 #include <errno.h>
 #include <cstring>
 #include <stdint.h>
 
+#include "trx.h"
 #include "ptt.h"
 #include "configuration.h"
 #include "rigMEM.h"
@@ -53,7 +60,7 @@
 #include "re.h"
 #include "debug.h"
 
-LOG_SET_SOURCE(debug::LOG_RIGCONTROL);
+LOG_FILE_SOURCE(debug::LOG_RIGCONTROL);
 
 using namespace std;
 
@@ -167,11 +174,28 @@ void PTT::close_all(void)
 
 void PTT::open_tty(void)
 {
+#ifdef __MINGW32__
+	serPort.Device(progdefaults.PTTdev);
+	serPort.RTS(progdefaults.RTSplus);
+	serPort.DTR(progdefaults.DTRplus);
+	serPort.RTSptt(progdefaults.RTSptt);
+	serPort.DTRptt(progdefaults.DTRptt);
+	if (serPort.OpenPort() == false) {
+		LOG_ERROR("Cannot open serial port %s", rigio.Device().c_str());
+		pttfd = -1;
+		return;
+	}
+	LOG_DEBUG("Serial port %s open", progdefaults.PTTdev.c_str());
+	pttfd = -1; // just a dummy return for this implementation
+
+#else
+
+#  if HAVE_TTYPORT
 	string pttdevName = progdefaults.PTTdev;
-#ifdef __CYGWIN__
+#    ifdef __CYGWIN__
 	// convert to Linux serial port naming
-	adjust_port(pttdevName);
-#endif
+	com_to_tty(pttdevName);
+#    endif
 
 	if ((pttfd = open(pttdevName.c_str(), O_RDWR | O_NOCTTY | O_NDELAY)) < 0) {
 		LOG_ERROR("Could not open \"%s\": %s", pttdevName.c_str(), strerror(errno));
@@ -194,21 +218,34 @@ void PTT::open_tty(void)
 		status &= ~TIOCM_DTR;		// clear DTR bit
 
 	ioctl(pttfd, TIOCMSET, &status);
-	LOG_DEBUG("Serial port %s open", progdefaults.PTTdev.c_str());
-    LOG_DEBUG("   status = %02X, %s", status, uint2bin(status, 8));
+	LOG_DEBUG("Serial port %s open; status = %02X, %s",
+		  progdefaults.PTTdev.c_str(), status, uint2bin(status, 8));
+#  endif // HAVE_TTYPORT
+#endif // __MINGW32__
 }
 
 void PTT::close_tty(void)
 {
+#ifdef __MINGW32__
+	serPort.ClosePort();
+	LOG_DEBUG("Serial port %s closed", progdefaults.PTTdev.c_str());
+#else
+#  if HAVE_TTYPORT
 	if (pttfd >= 0) {
 		tcsetattr(pttfd, TCSANOW, oldtio);
 		close(pttfd);
 	}
 	delete oldtio;
+#  endif // HAVE_TTYPORT
+#endif // __MINGW32__
 }
 
 void PTT::set_tty(bool ptt)
 {
+#ifdef __MINGW32__
+	serPort.SetPTT(ptt);
+#else
+#  if HAVE_TTYPORT
 	int status;
 	ioctl(pttfd, TIOCMGET, &status);
 
@@ -233,6 +270,8 @@ void PTT::set_tty(bool ptt)
 	}
 	LOG_DEBUG("Status %02X, %s", status & 0xFF, uint2bin(status, 8));
 	ioctl(pttfd, TIOCMSET, &status);
+#  endif // HAVE_TTYPORT
+#endif // __MINGW32__
 }
 
 #if HAVE_PARPORT
