@@ -1,11 +1,11 @@
 /*
- *    rigMEM.cxx  --  rigMEM (rig control) interface
+ *	rigMEM.cxx  --  rigMEM (rig control) interface
  *
  */
 
 #include <config.h>
 
-#if !defined(__CYGWIN__) && !defined(__APPLE__)
+#if !defined(__WOE32__) && !defined(__APPLE__)
 #  include <sys/ipc.h>
 #  include <sys/msg.h>
 #  include <sys/shm.h>
@@ -23,12 +23,15 @@
 #include "rigMEM.h"
 #include "fl_digi.h"
 #include "main.h"
+#include "trx.h"
 #include "rigsupport.h"
 #include "rigdialog.h"
 
 #include "debug.h"
 
-LOG_SET_SOURCE(debug::LOG_RIGCONTROL);
+using namespace std;
+
+LOG_FILE_SOURCE(debug::LOG_RIGCONTROL);
 
 /* ---------------------------------------------------------------------- */
 
@@ -45,16 +48,22 @@ static bool rigMEM_PTT = PTT_OFF;
 static bool rig_qsy = false;
 static bool TogglePTT = false;
 static bool rigMEMisPTT = false;
-static long long qsy_f;
-static long long qsy_fmid;
+static bool change_mode = false;
 
-#if !defined(__CYGWIN__) && !defined(__APPLE__)
+//static long long qsy_f;
+//static long long qsy_fmid;
+static long qsy_f;
+static long qsy_fmid;
+char szmode[80];
+
+#if !defined(__WOE32__) && !defined(__APPLE__)
 // Linux & *BSD interface to Kachina
 
 struct ST_SHMEM {
 	int  flag;
 	long freq;
 	long midfreq;
+	char mode[4];
 }sharedmem;
 
 
@@ -81,7 +90,7 @@ bool rigMEM_init(void)
 	noshare.flag = 2;
 	freqflag = &noshare;
 
-	shmid = shmget ((key_t)1234, sizeof(sharedmem), 0666 | IPC_CREAT);
+	shmid = shmget ((key_t)1234, sizeof(ST_SHMEM), 0666 | IPC_CREAT);
 
 	if (shmid < 0) {
 		LOG_ERROR("shmget failed");
@@ -98,16 +107,24 @@ bool rigMEM_init(void)
 	rigMEM_PTT = PTT_OFF;
 	TogglePTT = false;
 	rigMEMisPTT = false;
-	
+
+	freqflag->freq = 7070000L;
+	freqflag->midfreq = 1000L;
+	freqflag->flag = -1;
+	wf->carrier((int)qsy_fmid);
+	wf->rfcarrier(freqflag->freq);
+	wf->movetocenter();
+	show_frequency(freqflag->freq);
+
 	if (pthread_create(&rigMEM_thread, NULL, rigMEM_loop, NULL) < 0) {
 		LOG_ERROR("rigMEM init: pthread_create failed");
 		return false;
-	} 
+	}
 
 	rigMEM_enabled = true;
-	
+
 	init_rigMEM_RigDialog();
-		
+
 	return true;
 }
 
@@ -134,33 +151,33 @@ static void *rigMEM_loop(void *args)
 
 	int sb = true;
 
-	freqflag->freq = 0L;
-	freqflag->flag = -1;
-
 	for (;;) {
 	/* see if we are being canceled */
 		if (rigMEM_exit)
 			break;
 
-//		MilliSleep(20);
-
-		if (rig_qsy) {
-			freqflag->freq = qsy_f;
-			freqflag->flag = -2; // set frequency
-			MilliSleep(20);
-			if (qsy_fmid > 0) {
-				if (active_modem->freqlocked() == true) {
-					active_modem->set_freqlock(false);
-					active_modem->set_freq((int)qsy_fmid);
-					active_modem->set_freqlock(true);
+		if (rig_qsy || change_mode) {
+			if (rig_qsy) {
+				freqflag->freq = qsy_f;
+				if (qsy_fmid > 0) {
+					if (active_modem->freqlocked() == true) {
+						active_modem->set_freqlock(false);
+						active_modem->set_freq((int)qsy_fmid);
+						active_modem->set_freqlock(true);
+					} else
+						active_modem->set_freq((int)qsy_fmid);
+					wf->carrier((int)qsy_fmid);
+					wf->rfcarrier(freqflag->freq);
+					wf->movetocenter();
 				} else
-					active_modem->set_freq((int)qsy_fmid);
-				wf->carrier((int)qsy_fmid);
-				wf->rfcarrier(freqflag->freq);
-				wf->movetocenter();
-			} else
-				wf->rfcarrier(freqflag->freq);
-			rig_qsy = false;
+					wf->rfcarrier(freqflag->freq);
+				rig_qsy = false;
+			}
+			if (change_mode) {
+				strncpy(freqflag->mode, szmode, 4);
+				change_mode = false;
+			}
+			freqflag->flag = -2;
 		} else if (TogglePTT) {
 			if (rigMEM_PTT == PTT_ON)
 				freqflag->flag = -3;
@@ -168,17 +185,16 @@ static void *rigMEM_loop(void *args)
 				freqflag->flag = -4;
 			TogglePTT = false;
 			MilliSleep(20);
-		}// else
-//			MilliSleep(20);
+		}
 
 		if (freqflag->flag >= 0) {
 			freqflag->flag = -1; // read frequency
 			sb = false;
 		}
-	/* delay for 20 msec interval */
+/* delay for 20 msec interval */
 		MilliSleep(20);
 
-	/* if rigMEM control program running it will update the freqflag structure every 10 msec */
+/* if rigMEM control program running it will update the freqflag structure every 10 msec */
 		if (freqflag->flag > -1) {
 			if ((freqflag->flag & 0x10) == 0x10)
 				rigMEMisPTT = true;
@@ -186,30 +202,18 @@ static void *rigMEM_loop(void *args)
 				sb = false;
 			else
 				sb = true;
-			
+
 			if (wf->rfcarrier() != freqflag->freq)
 				wf->rfcarrier(freqflag->freq);
-			if (FreqDisp->value() != freqflag->freq)
-				FreqDisp->value(freqflag->freq);
-			if (qsoFreqDisp->value() != freqflag->freq)
-				qsoFreqDisp->value(freqflag->freq);
-
-			if (wf->USB() != sb)
-				wf->USB(sb);
-			if (sb && (strcmp(opMODE->value(), "USB") || strcmp(qso_opMODE->value(),"USB"))) {
-				REQ(&Fl_ComboBox::put_value, opMODE, "USB");
-				REQ(&Fl_ComboBox::put_value, qso_opMODE, "USB");
-			}
-			if (!sb && (strcmp(opMODE->value(), "LSB") || strcmp(qso_opMODE->value(),"LSB"))) {
-				REQ(&Fl_ComboBox::put_value, opMODE, "LSB");
-				REQ(&Fl_ComboBox::put_value, qso_opMODE, "LSB");
-			}
+			show_frequency(freqflag->freq);
+			wf->USB(sb);
+			REQ (&Fl_ComboBox::put_value, opMODE, sb ? "USB" : "LSB");
+			REQ (&Fl_ComboBox::put_value, qso_opMODE, sb ? "USB" : "LSB");
 		}
 	}
 
-	if (shmdt(shared_memory) == -1) {
-		fl_message("shmdt failed");
-	}
+	if (shmdt(shared_memory) == -1)
+		LOG_PERROR("shmdt");
 
 	shmid = -1;
 
@@ -217,7 +221,7 @@ static void *rigMEM_loop(void *args)
 	return NULL;
 }
 
-#elif defined(__CYGWIN__) // __CYGWIN__
+#elif defined(__WOE32__)
 //===================================================
 // Windows interface to Kachina / rigCAT
 //
@@ -227,22 +231,26 @@ FILE *IOin;
 int  IOflag;
 long IOfreq = 7070000L;
 long IOmidfreq = 1000L;
-char szmode[80];
 
-bool rigMEM_init(void) 
-{ 
+bool rigMEM_init(void)
+{
 	rigMEM_enabled = false;
 
 	rig_qsy = false;
 	rigMEM_PTT = PTT_OFF;
 	TogglePTT = false;
 	rigMEMisPTT = false;
-	
+	qsy_f = wf->rfcarrier();
+	qsy_fmid = 0;
+
 	if (pthread_create(&rigMEM_thread, NULL, rigMEM_loop, NULL) < 0) {
-		fl_message("rigMEM init: pthread_create failed");
+		LOG_PERROR("pthread_create");
 		return false;
-	} 
+	}
 	rigMEM_enabled = true;
+
+	init_rigMEM_RigDialog();
+
 	return true;
 }
 
@@ -277,56 +285,39 @@ static void *rigMEM_loop(void *args)
 		if (rigMEM_exit)
 			break;
 
-//		if (rig_qsy) {
-//			freqflag->freq = qsy_f;
-//			freqflag->flag = -2; // set frequency
-//			MilliSleep(20);
-//			if (active_modem->freqlocked() == true) {
-//				active_modem->set_freqlock(false);
-//				active_modem->set_freq((int)qsy_fmid);
-//				active_modem->set_freqlock(true);
-//			} else
-//				active_modem->set_freq((int)qsy_fmid);
-//			wf->carrier((int)qsy_fmid);
-//			wf->rfcarrier(freqflag->freq);
-//			wf->movetocenter();
-//			rig_qsy = false;
-//		} else if (TogglePTT) {
-		if (TogglePTT) {
+		if (TogglePTT || rig_qsy || change_mode) {
 			IOout = fopen("c:/RIGCTL/ptt", "w");
 			if (IOout) {
-				if (rigMEM_PTT == PTT_ON)
-					putc('X', IOout);
-				else
-					putc('R', IOout);
-				fclose(IOin);
-				TogglePTT = false;
+LOG_INFO("sent %d, %c, %s",
+	(int)qsy_f,
+	rigMEM_PTT == PTT_ON ? 'X' : 'R',
+	szmode);
+				fprintf(IOout,"%c\n", rigMEM_PTT == PTT_ON ? 'X' : 'R');
+				fprintf(IOout,"%d\n", (int)qsy_f);
+				fprintf(IOout,"%s\n", szmode);
+				fclose(IOout);
+				if (TogglePTT) TogglePTT = false;
+				if (rig_qsy) rig_qsy = false;
+				if (change_mode) change_mode = false;
+				show_frequency(qsy_f);
 			}
 		}
-		
+
 		IOin = fopen("c:/RIGCTL/rig", "r");
 		if (IOin) {
 			fscanf(IOin, "%ld\n", &IOfreq);
 			fscanf(IOin, "%s", szmode);
 			fclose(IOin);
-		}
-		if (strcmp(szmode,"LSB") == 0)
-			sb = false;
-			
-		if (wf->rfcarrier() != IOfreq) {
+			remove("c:/RIGCTL/rig");
+LOG_INFO("rcvd %d, %s", (int)IOfreq, szmode);
+
 			wf->rfcarrier(IOfreq);
-			FreqDisp->value(IOfreq);
-			qsoFreqDisp->value(IOfreq);
-		}
-		if (wf->USB() != sb) {
+			show_frequency(IOfreq);
+			qsy_f = IOfreq;
+			sb = (strcmp(szmode, "USB") == 0);
 			wf->USB(sb);
-			if (sb) {
-				REQ(&Fl_ComboBox::put_value, opMODE, "USB");
-				REQ(&Fl_ComboBox::put_value, qso_opMODE, "USB");
-			} else  {
-				REQ(&Fl_ComboBox::put_value, opMODE, "LSB");
-				REQ(&Fl_ComboBox::put_value, qso_opMODE, "LSB");
-			}
+			REQ (&Fl_ComboBox::put_value, opMODE, sb ? "USB" : "LSB");
+			REQ (&Fl_ComboBox::put_value, qso_opMODE, sb ? "USB" : "LSB");
 		}
 
 // delay for 50 msec interval
@@ -357,7 +348,7 @@ bool rigMEM_CanPTT(void)
 {
 	return rigMEMisPTT;
 }
-	
+
 void setrigMEM_PTT (bool on)
 {
   rigMEM_PTT = on;
@@ -369,8 +360,16 @@ void rigMEM_set_qsy(long long f, long long fmid)
 	if (!rigMEM_enabled)
 		return;
 
+	if (active_modem->freqlocked() == true) {
+		active_modem->set_freqlock(false);
+		active_modem->set_freq(fmid);
+		active_modem->set_freqlock(true);
+	} else
+		active_modem->set_freq(fmid);
+	wf->rfcarrier(f);
+	wf->movetocenter();
+
 	qsy_f = f;
-	qsy_fmid = fmid;
 	rig_qsy = true;
 }
 
@@ -380,14 +379,17 @@ void rigMEM_set_freq(long long f)
 		return;
 
 	qsy_f = f;
-	qsy_fmid = 0;
+	wf->rfcarrier(f);
 	rig_qsy = true;
 
 }
 
 void rigMEM_setmode(const string& s)
 {
-	return; // not implemented for memMAP
+	strncpy(szmode, s.c_str(), 4);
+	wf->USB( strcmp(szmode,"USB") == 0 );
+	change_mode = true;
+	return;
 }
 
 /* ---------------------------------------------------------------------- */
