@@ -9,7 +9,7 @@
 #include "rigclass.h"
 #include "debug.h"
 
-LOG_SET_SOURCE(debug::LOG_RIGCONTROL);
+LOG_FILE_SOURCE(debug::LOG_RIGCONTROL);
 
 #define NUMTRIES 5
 
@@ -22,7 +22,7 @@ Rig::Rig(rig_model_t rig_model)
 {
 	rig = rig_init(rig_model);
    	if (!rig)
-		throw RigException ("init");
+		throw RigException ("Could not initialize rig");
 }
 
 Rig::~Rig()
@@ -34,7 +34,7 @@ void Rig::init(rig_model_t rig_model)
 {
 	close();
 	if ((rig = rig_init(rig_model)) == NULL)
-		throw RigException ("init");
+		throw RigException ("Could not initialize rig");
 	LOG_INFO("Initialised rig model %d: %s", rig_model, getName());
 }
 
