@@ -11,6 +11,10 @@
 #include <config.h>
 
 #include <fstream>
+#include <string>
+#include <list>
+
+#include <FL/filename.H>
 
 #include "rigio.h"
 #include "rigxml.h"
@@ -26,6 +30,8 @@
 #include "fileselect.h"
 #include "confdialog.h"
 
+using namespace std;
+
 //#define DEBUGXML
 
 void parseRIGDEF(size_t &);
@@ -50,6 +56,10 @@ void parseTIMEOUT(size_t &);
 void parseBAUDRATE(size_t &);
 void parseRTSCTS(size_t &);
 void parseCMDPTT(size_t &);
+void parseRTSPLUS(size_t &);
+void parseDTRPLUS(size_t &);
+void parseRTSPTT(size_t &);
+void parseDTRPTT(size_t &);
 void parseECHO(size_t &);
 
 void parseIOSsymbol(size_t &);
@@ -113,6 +123,10 @@ TAGS rigdeftags[] = {
 	{"<TIMEOUT", parseTIMEOUT},
 	{"<BAUDRATE", parseBAUDRATE},
 	{"<RTSCTS", parseRTSCTS},
+	{"<RTSPLUS", parseRTSPLUS},
+	{"<DTRPLUS", parseDTRPLUS},
+	{"<RTSPTT", parseRTSPTT},
+	{"<DTRPTT", parseDTRPTT},
 	{"<ECHO", parseECHO},
 	{"<CMDPTT", parseCMDPTT},
 	{0, 0} 
@@ -519,6 +533,38 @@ void parseRTSCTS(size_t &p0){
 	p0 = pend;
 }
 
+void parseRTSPLUS(size_t &p0)
+{
+	bool val = getBool(p0);
+	xmlrig.rts = val;
+	size_t pend = tagEnd(p0);
+	p0 = pend;
+}
+
+void parseDTRPLUS(size_t &p0)
+{
+	bool val = getBool(p0);
+	xmlrig.dtr = val;
+	size_t pend = tagEnd(p0);
+	p0 = pend;
+}
+
+void parseRTSPTT(size_t &p0)
+{
+	bool val = getBool(p0);
+	xmlrig.rtsptt = val;
+	size_t pend = tagEnd(p0);
+	p0 = pend;
+}
+
+void parseDTRPTT(size_t &p0)
+{
+	bool val = getBool(p0);
+	xmlrig.dtrptt = val;
+	size_t pend = tagEnd(p0);
+	p0 = pend;
+}
+
 void parseCMDPTT(size_t &p0) {
     bool val = getBool(p0);
     xmlrig.cmdptt = val;
