@@ -36,10 +36,9 @@
 
 #include <cstdio>
 #include <cstdlib>
-#include <errno.h>
+#include <cerrno>
 #include <unistd.h>
 
-#include <sys/ioctl.h>
 #include <fcntl.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -47,6 +46,7 @@
 #include <limits.h>
 
 #if USE_OSS
+#    include <sys/ioctl.h>
 #    include <sys/soundcard.h>
 #endif
 #include <math.h>
@@ -59,13 +59,16 @@
 #include "configuration.h"
 #include "status.h"
 #include "fileselect.h"
-
-#include "threads.h" 
+#include "trx.h"
+#include "fl_digi.h"
+#include "threads.h"
 #include "timeops.h"
 #include "ringbuffer.h"
 #include "debug.h"
 
-LOG_SET_SOURCE(debug::LOG_AUDIO);
+using namespace std;
+
+LOG_FILE_SOURCE(debug::LOG_AUDIO);
 
 // Define these constants here to avoid littering the code with magic numbers.
 // Audio input is mono in SoundPort and SoundPulse, stereo in SoundOSS
@@ -77,14 +80,6 @@ LOG_SET_SOURCE(debug::LOG_AUDIO);
 // We never write duplicate/QSK/PseudoFSK data to the sound files
 #define SNDFILE_CHANNELS 1
 
-// Unnamed sempahores are not supported on OS X,
-// and named semaphores are broken on cygwin.
-#ifdef __APPLE__
-#  define USE_NAMED_SEMAPHORES 1
-#else
-#  define USE_NAMED_SEMAPHORES 0
-#endif
-
 SoundBase::SoundBase()
         : sample_frequency(0),
 	  txppm(progdefaults.TX_corr), rxppm(progdefaults.RX_corr),
@@ -116,11 +111,11 @@ SoundBase::~SoundBase()
 void SoundBase::get_file_params(const char* def_fname, const char** fname, int* format)
 {
 	std::string filters = "Waveform Audio Format\t*.wav\n" "AU\t*.{au,snd}\n";
-// FIXME: we shouldn't need this conditional
-# ifndef __CYGWIN__
-	if (format_supported(SF_FORMAT_FLAC | SF_FORMAT_PCM_16))
+	int nfilt = 2;
+	if (format_supported(SF_FORMAT_FLAC | SF_FORMAT_PCM_16)) {
 		filters += "Free Lossless Audio Codec\t*.flac";
-# endif
+		nfilt++;
+	}
 
 	int fsel;
 	if (strstr(def_fname, "playback"))
@@ -130,6 +125,8 @@ void SoundBase::get_file_params(const char* def_fname, const char** fname, int*
 	if (!*fname)
 		return;
 
+	if (fsel >= nfilt) // "Default" save-as type on OS X
+		fsel = 0;
 	switch (fsel) {
 	case 0:
 		*format = SF_FORMAT_WAV | SF_FORMAT_PCM_16;
@@ -265,8 +262,15 @@ sf_count_t SoundBase::write_file(SNDFILE* file, double* buf, size_t count)
 bool SoundBase::format_supported(int format)
 {
 
-        SF_INFO fmt_test = { 0, sample_frequency, SNDFILE_CHANNELS, format, 0, 0 };
-        return sf_format_check(&fmt_test);
+	SF_INFO info = { 0, sample_frequency, SNDFILE_CHANNELS, format, 0, 0 };
+	FILE* f;
+	if ((f = tmpfile()) == NULL)
+		return false;
+	SNDFILE* sndf = sf_open_fd(fileno(f), SFM_WRITE, &info, SF_FALSE);
+	fclose(f);
+	if (sndf)
+		sf_close(sndf);
+	return sndf;
 }
 
 void SoundBase::tag_file(SNDFILE *sndfile, const char *title)
@@ -289,7 +293,7 @@ void SoundBase::tag_file(SNDFILE *sndfile, const char *title)
 	time_t t = time(0);
 	struct tm zt;
 	(void)gmtime_r(&t, &zt);
-	if (strftime(s, sizeof(s), "%F %Tz", &zt) > 0)
+	if (strftime(s, sizeof(s), "%Y-%m-%dT%H:%M:%Sz", &zt) > 0)
 		sf_set_string(sndfile, SF_STR_DATE, s);
 }
 #endif // USE_SNDFILE
@@ -763,7 +767,7 @@ SoundPort::SoundPort(const char *in_dev, const char *out_dev)
 #endif
         for (size_t i = 0; i < sizeof(sems)/sizeof(*sems); i++) {
 #if USE_NAMED_SEMAPHORES
-		snprintf(sname, sizeof(sname), "%zu-%u-%s", i, getpid(), PACKAGE_TARNAME);
+		snprintf(sname, sizeof(sname), "%" PRIuSZ "-%u-%s", i, getpid(), PACKAGE_TARNAME);
 		if ((*sems[i] = sem_open(sname, O_CREAT | O_EXCL, 0600, 0)) == (sem_t*)SEM_FAILED)
 			throw SndException(errno);
 #  if HAVE_SEM_UNLINK
@@ -968,7 +972,7 @@ size_t SoundPort::Read(double *buf, size_t count)
 			for (size_t i = 0; i < count; i++)
 				buf[i] *= progStatus.RcvMixer;
 		if (!capture) {
-			usleep((useconds_t)ceil((1e6 * count) / req_sample_rate));
+			MilliSleep((long)ceil((1e3 * count) / req_sample_rate));
 			return count;
 		}
 	}
@@ -1182,13 +1186,13 @@ void SoundPort::src_data_reset(unsigned dir)
                                   MIN(req_sample_rate, sd[dir].dev_sample_rate)));
         if (dir == 0) {
                 rbsize = 2 * MAX(rbsize, 4096);
-		LOG_DEBUG("input rbsize=%zu", rbsize);
+		LOG_DEBUG("input rbsize=%" PRIuSZ "", rbsize);
         }
         else if (dir == 1) {
                 if (req_sample_rate > 8000)
                         rbsize *= 2;
                 rbsize = MAX(rbsize, 2048);
-		LOG_DEBUG("output rbsize=%zu", rbsize);
+		LOG_DEBUG("output rbsize=%" PRIuSZ "", rbsize);
         }
         if (!sd[dir].rb || sd[dir].rb->length() != rbsize) {
                 delete sd[dir].rb;
@@ -1509,7 +1513,7 @@ void SoundPort::pa_perror(int err, const char* str)
 
 void SoundPort::init_hostapi_ext(void)
 {
-#if HAVE_DLOPEN && !defined(__CYGWIN__)
+#if HAVE_DLOPEN && !defined(__WOE32__)
 	void* handle = dlopen(NULL, RTLD_LAZY);
 	if (!handle)
 		return;
@@ -1740,7 +1744,7 @@ size_t SoundPulse::Read(double *buf, size_t count)
 			for (size_t i = 0; i < count; i++)
 				buf[i] *= progStatus.RcvMixer;
 		if (!capture) {
-			usleep((useconds_t)ceil((1e6 * count) / sample_frequency));
+			MilliSleep((long)ceil((1e3 * count) / sample_frequency));
 			return count;
 		}
 	}
@@ -1810,7 +1814,7 @@ size_t SoundNull::Write(double* buf, size_t count)
 		write_file(ofGenerate, buf, count);
 #endif
 
-	usleep((useconds_t)ceil((1e6 * count) / sample_frequency));
+	MilliSleep((long)ceil((1e3 * count) / sample_frequency));
 
 	return count;
 }
@@ -1822,7 +1826,7 @@ size_t SoundNull::Write_stereo(double* bufleft, double* bufright, size_t count)
 		write_file(ofGenerate, bufleft, count);
 #endif
 
-	usleep((useconds_t)ceil((1e6 * count) / sample_frequency));
+	MilliSleep((long)ceil((1e3 * count) / sample_frequency));
 
 	return count;
 }
@@ -1844,7 +1848,7 @@ size_t SoundNull::Read(double *buf, size_t count)
 		write_file(ofCapture, buf, count);
 #endif
 
-	usleep((useconds_t)ceil((1e6 * count) / sample_frequency));
+	MilliSleep((long)ceil((1e3 * count) / sample_frequency));
 
 	return count;
 }
