@@ -7,6 +7,9 @@
 
 #include <cstdlib>
 #include <cstring>
+#if USE_OSS
+#  include <glob.h>
+#endif
 
 #include "soundconf.h"
 #include "sound.h"
@@ -15,7 +18,7 @@
 #include "confdialog.h"
 #include "debug.h"
 
-LOG_SET_SOURCE(debug::LOG_AUDIO);
+LOG_FILE_SOURCE(debug::LOG_AUDIO);
 
 using namespace std;
 
@@ -43,7 +46,7 @@ static void init_oss(void)
 	menuMix->value(progdefaults.MXdevice.c_str());
 #else
 	progdefaults.EnableMixer = false;
-        tabMixer->deactivate();
+	tabMixer->parent()->remove(*tabMixer);
 #endif // USE_OSS
 }
 
@@ -70,12 +73,37 @@ public:
 	PaHostApiTypeId api;
 };
 
-#endif // USE_PORTAUDIO
+static PaDeviceIndex get_default_portaudio_device(int dir)
+{
+#ifndef __linux__
+	goto ret_def;
+#else
+	// Recent PortAudio snapshots prefer ALSA over OSS for the default device, but there are
+	// still versions out there that try OSS first.  We check the default host api type and,
+	// if it is not ALSA, return the ALSA default device instead.
+	PaHostApiIndex api_idx;
+	if ((api_idx = Pa_GetDefaultHostApi()) < 0)
+		goto ret_def;
+	const PaHostApiInfo* host_api;
+	if ((host_api = Pa_GetHostApiInfo(api_idx)) == NULL || host_api->type == paALSA)
+		goto ret_def;
 
+	LOG_DEBUG("Default host API is %s, trying default ALSA %s device instead",
+		  host_api->name, (dir == 0 ? "input" : "output"));
+	api_idx = Pa_GetHostApiCount();
+	if (api_idx < 0)
+		goto ret_def;
+	for (PaHostApiIndex i = 0; i < api_idx; i++)
+		if ((host_api = Pa_GetHostApiInfo(i)) && host_api->type == paALSA)
+			return dir == 0 ? host_api->defaultInputDevice : host_api->defaultOutputDevice;
+#endif // __linux__
+
+ret_def:
+	return dir == 0 ? Pa_GetDefaultInputDevice() : Pa_GetDefaultOutputDevice();
+}
 
 static void init_portaudio(void)
 {
-#if USE_PORTAUDIO
 	try {
 		SoundPort::initialize();
 	}
@@ -91,7 +119,7 @@ static void init_portaudio(void)
 #if defined(__APPLE__)
 	pa_api_prio[paASIO] = 0;
 	pa_api_prio[paCoreAudio] = 1;
-#elif defined(__CYGWIN__)
+#elif defined(__WOE32__)
 	pa_api_prio[paASIO] = 0;
 	pa_api_prio[paWASAPI] = 1;
 	pa_api_prio[paMME] = 2;
@@ -135,7 +163,7 @@ static void init_portaudio(void)
 
 	if (progdefaults.PortInDevice.length() == 0) {
 		if (progdefaults.PAdevice.length() == 0) {
-			PaDeviceIndex def = Pa_GetDefaultInputDevice();
+			PaDeviceIndex def = get_default_portaudio_device(0);
 			if (def != paNoDevice) {
 				progdefaults.PortInDevice = (*(SoundPort::devices().begin() + def))->name;
 				progdefaults.PortInIndex = def;
@@ -147,7 +175,7 @@ static void init_portaudio(void)
 
 	if (progdefaults.PortOutDevice.length() == 0) {
 		if (progdefaults.PAdevice.length() == 0) {
-			PaDeviceIndex def = Pa_GetDefaultOutputDevice();
+			PaDeviceIndex def = get_default_portaudio_device(1);
 			if (def != paNoDevice) {
 				progdefaults.PortOutDevice = (*(SoundPort::devices().begin() + def))->name;
 				progdefaults.PortOutIndex = def;
@@ -193,8 +221,10 @@ static void init_portaudio(void)
 		menuPortOutDev->value(idx);
 		menuPortOutDev->set_changed();
 	}
-#endif
 }
+#else
+static void init_portaudio(void) { }
+#endif // USE_PORTAUDIO
 
 static void build_srate_menu(Fl_Menu_* menu, const double* rates, size_t length, double defrate = -1.0)
 {
