@@ -27,21 +27,48 @@
 
 #include <config.h>
 
-#include <sys/utsname.h>
+#ifdef __MINGW32__
+#  include "compat.h"
+#endif
+
+#if HAVE_SYS_UTSNAME_H
+#  include <sys/utsname.h>
+#endif
+
 #include <sys/time.h>
-#include <arpa/inet.h>
+#if HAVE_ARPA_INET_H
+#  include <arpa/inet.h>
+#endif
 
 #include <stdint.h>
 #include <cstring>
 #include <cstdlib>
 
 #include <string>
-#include <map>
 #include <deque>
 #include <vector>
 #include <algorithm>
 #include <fstream>
 
+#if (__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 1)
+#  define MAP_TYPE std::tr1::unordered_map
+#define HASH_TYPE std::tr1::hash
+#  include <tr1/unordered_map>
+#else
+// use the non-standard gnu hash_map on gcc <= 4.0.x,
+// which has a broken tr1::unordered_map::operator=
+#  define MAP_TYPE __gnu_cxx::hash_map
+#define HASH_TYPE __gnu_cxx::hash
+#  include <ext/hash_map>
+namespace __gnu_cxx {
+	// define the missing hash specialisation for std::string
+	// using the 'const char*' hash function
+	template<> struct hash<std::string> {
+		size_t operator()(const std::string& s) const { return __stl_hash_string(s.c_str()); }
+	};
+}
+#endif
+
 #include <FL/Fl.H>
 
 #include "socket.h"
@@ -49,28 +76,18 @@
 #include "debug.h"
 #include "util.h"
 #include "trx.h"
-#include "waterfall.h"
+#include "fl_digi.h"
+#include "main.h"
 #include "configuration.h"
 #include "globals.h"
 #include "spot.h"
 
 #include "pskrep.h"
 
-LOG_SET_SOURCE(debug::LOG_SPOTTER);
+LOG_FILE_SOURCE(debug::LOG_SPOTTER);
 
 // -------------------------------------------------------------------------------------------------
 
-// The regular expression that matches the spotter's buffer when it calls us.
-// It must define at least two capturing groups, the second of which is the
-// spotted callsign.
-#define CALLSIGN_RE "[[:alnum:]]?[[:alpha:]/]+[[:digit:]]+[[:alnum:]/]+"
-#if HAVE_REGEX_BACKREF
-#  define PSKREP_RE "(de|cq|qrz)[^[:alnum:]/\n]+"  "(" CALLSIGN_RE ")"  " +(.* +)?\\2[^[:alnum:]]+$"
-#else
-#  define PSKREP_RE "(de|cq|qrz)[^[:alnum:]/\n]+"  "(" CALLSIGN_RE ")"  " +(.* +)?" \
-	"(" CALLSIGN_RE ")" "[^[:alnum:]]+$"
-#endif
-
 // Try to flush the report queue every SEND_INTERVAL seconds.
 #define SEND_INTERVAL 300
 
@@ -95,7 +112,7 @@ LOG_SET_SOURCE(debug::LOG_SPOTTER);
 
 using namespace std;
 
-enum status_t { STATUS_NEW, STATUS_PENDING, STATUS_SENT };
+enum status_t { PSKR_STATUS_NEW, PSKR_STATUS_PENDING, PSKR_STATUS_SENT };
 enum rtype_t { PSKREP_AUTO = 1, PSKREP_LOG = 2, PSKREP_MANUAL = 3 };
 
 struct rcpt_report_t
@@ -103,7 +120,7 @@ struct rcpt_report_t
 	rcpt_report_t(trx_mode m = 0, long long f = 0, time_t t = 0,
 		      rtype_t p = PSKREP_AUTO, string loc = "")
 		: mode(m), freq(f), rtime(t), rtype(p),
-		  status(STATUS_NEW), locator(loc) { }
+		  status(PSKR_STATUS_NEW), locator(loc) { }
 
 	trx_mode mode;
 	long long freq;
@@ -118,10 +135,9 @@ struct rcpt_report_t
 // A band_map_t holds a list of reception reports (for a particular callsign and band)
 typedef deque<rcpt_report_t> band_map_t;
 // A call_map_t holds reception reports for a particular callsign
-typedef map<band_t, band_map_t> call_map_t;
+typedef MAP_TYPE<band_t, band_map_t, HASH_TYPE<int> > call_map_t;
 // A container of this type holds all reception reports, sorted by callsign and band
-typedef map<string, call_map_t> queue_t;
-
+typedef MAP_TYPE<string, call_map_t> queue_t;
 
 class pskrep_sender
 {
@@ -178,7 +194,7 @@ public:
 	       bool reg_auto, bool reg_log, bool reg_manual);
 	~pskrep();
 
-	static void recv(int afreq, const char* str, const regmatch_t* calls, size_t len, void* obj);
+	static void recv(trx_mode mode, int afreq, const char* str, const regmatch_t* calls, size_t len, void* obj);
 	static void log(const char* call, const char* loc, long long freq, trx_mode mode, time_t rtime, void* obj);
 	static void manual(const char* call, const char* loc, long long freq, trx_mode mode, time_t rtime, void* obj);
 	bool progress(void);
@@ -195,7 +211,7 @@ private:
 
 	static bool not_sent(const band_map_t::value_type& r)
 	{
-		return r.status != STATUS_SENT;
+		return r.status != PSKR_STATUS_SENT;
 	}
 
 	queue_t queue;
@@ -263,9 +279,9 @@ static void pskrep_make_id(string& id, size_t len)
 		unsigned seed = time(NULL);
 		if (!progdefaults.myCall.empty())
 			seed ^= simple_hash_str((const unsigned char*)progdefaults.myCall.c_str());
-		srandom(seed);
+		srand(seed);
 		for (size_t i = 0; i < len; i++)
-			while (!isgraph(id[i] = random() % 0x7F));
+			while (!isgraph(id[i] = rand() % 0x7F));
 	}
 }
 
@@ -345,18 +361,12 @@ pskrep::~pskrep()
 }
 
 // This function is called by spot_recv() when its buffer matches our PSKREP_RE
-void pskrep::recv(int afreq, const char* str, const regmatch_t* calls, size_t len, void* obj)
+void pskrep::recv(trx_mode mode, int afreq, const char* str, const regmatch_t* calls, size_t len, void* obj)
 {
-	if (unlikely(calls[2].rm_so == -1 || calls[2].rm_eo == -1))
+	if (unlikely(calls[PSKREP_RE_INDEX].rm_so == -1 || calls[PSKREP_RE_INDEX].rm_eo == -1))
 		return;
 
-#if !HAVE_REGEX_BACKREF // workaround for systems without support for RE back refs
-	if (calls[4].rm_eo - calls[4].rm_so != calls[2].rm_eo - calls[2].rm_so ||
-	    strncasecmp(str + calls[2].rm_so, str + calls[4].rm_so, calls[2].rm_eo - calls[2].rm_so))
-		return;
-#endif
-
-	string call(str, calls[2].rm_so, calls[2].rm_eo - calls[2].rm_so);
+	string call(str + calls[PSKREP_RE_INDEX].rm_so, calls[PSKREP_RE_INDEX].rm_eo - calls[PSKREP_RE_INDEX].rm_so);
 	long long freq = afreq;
 	if (!wf->USB())
 		freq = -freq;
@@ -401,7 +411,7 @@ void pskrep::append(string call, const char* loc, long long freq, trx_mode mode,
 	}
 	else if (!bandq.empty()) {
 		band_map_t::value_type& r = bandq.back();
-		if (r.status != STATUS_SENT && *loc && r.locator != loc) { // update last
+		if (r.status != PSKR_STATUS_SENT && *loc && r.locator != loc) { // update last
 			r.locator = loc;
 			r.rtype = rtype;
 			LOG_INFO("Updated (call=\"%s\", loc=\"%s\", mode=\"%s\", freq=%lld, time=%jd, type=%u)",
@@ -423,14 +433,14 @@ bool pskrep::progress(void)
 		for (call_map_t::iterator j = i->second.begin(); j != i->second.end(); ++j) {
 			for (band_map_t::iterator k = j->second.begin(); k != j->second.end(); ++k) {
 				switch (k->status) {
-				case STATUS_NEW:
+				case PSKR_STATUS_NEW:
 					if ((sender_full = !sender.append(i->first, *k)))
 						goto send_reports;
-					k->status = STATUS_PENDING;
+					k->status = PSKR_STATUS_PENDING;
 					nrep++;
 					break;
-				case STATUS_PENDING: // sent in last cycle
-					k->status = STATUS_SENT;
+				case PSKR_STATUS_PENDING: // sent in last cycle
+					k->status = PSKR_STATUS_SENT;
 				default:
 					break;
 				}
@@ -468,7 +478,7 @@ void pskrep::gc(void)
 			rm += k - b.begin();
 			k = b.erase(b.begin(), k);
 
-			if (k != b.end() && k->status == STATUS_SENT && k->rtime <= threshold) {
+			if (k != b.end() && k->status == PSKR_STATUS_SENT && k->rtime <= threshold) {
 				b.erase(k);
 				rm++;
 			}
@@ -517,8 +527,8 @@ void pskrep::load_queue(void)
 	for (queue_t::iterator i = queue.begin(); i != queue.end(); ++i)
 		for (call_map_t::iterator j = i->second.begin(); j != i->second.end(); ++j)
 			for (band_map_t::iterator k = j->second.begin(); k != j->second.end(); ++k)
-				if (k->status == STATUS_PENDING)
-					k->status = STATUS_NEW;
+				if (k->status == PSKR_STATUS_PENDING)
+					k->status = PSKR_STATUS_NEW;
 }
 
 // -------------------------------------------------------------------------------------------------
@@ -773,7 +783,7 @@ bool pskrep_sender::send(void)
 
 	// empty dgram or no reports (shouldn't happen)
 	if (dgram_size == 0 || dgram_size == report_offset + 4) {
-		LOG_DEBUG("Not sending empty dgram: %zu %zu", dgram_size, report_offset);
+		LOG_DEBUG("Not sending empty dgram: %" PRIuSZ " %" PRIuSZ "", dgram_size, report_offset);
 		return false;
 	}
 
@@ -793,7 +803,7 @@ bool pskrep_sender::send(void)
 	*reinterpret_cast<uint32_t*>(dgram + 4) = htonl(time(NULL));
 
 	bool ret;
-	LOG_DEBUG("Sending datagram (%zu): \"%s\"", dgram_size, str2hex(dgram, dgram_size));
+	LOG_DEBUG("Sending datagram (%" PRIuSZ "): \"%s\"", dgram_size, str2hex(dgram, dgram_size));
 	try {
 		if ((size_t)send_socket->send(dgram, dgram_size) != dgram_size)
 			throw SocketException("short write");
