@@ -22,8 +22,9 @@
 
 #include <config.h>
 
-#include <vector>
-#include <map>
+#include <list>
+#include <tr1/unordered_map>
+#include <functional>
 
 #include "trx.h"
 #include "globals.h"
@@ -32,57 +33,55 @@
 #include "debug.h"
 #include "spot.h"
 
+// the number of characters that we match our REs against
 #define SEARCHLEN 32
 #define DECBUFSIZE 8 * SEARCHLEN
 
 
 using namespace std;
 
-struct callback_t {
+struct callback_t
+{
 	void* data;
-
 	spot_log_cb_t lcb;
-
 	spot_log_cb_t mcb;
-
 	spot_recv_cb_t rcb;
-	fre_t* re;
+};
+typedef list<callback_t> cblist_t;
+
+
+struct fre_hash : std::unary_function<const fre_t*, size_t>
+{
+	size_t operator()(const fre_t* r) const { return r->hash(); }
+};
+struct fre_comp : std::unary_function<const fre_t*, bool>
+{
+	size_t operator()(const fre_t* l, const fre_t* r) const { return *l == *r; }
 };
 
-static map<int, string> buffers;
-typedef vector<callback_t> cblist_t;
-
+typedef list<callback_t*> callback_p_list_t;
+typedef tr1::unordered_map<fre_t*, callback_p_list_t, fre_hash, fre_comp> rcblist_t;
 
+static tr1::unordered_map<int, string> buffers;
 static cblist_t cblist;
+static rcblist_t rcblist;
 
 void spot_recv(char c, int decoder, int afreq)
 {
 	static trx_mode last_mode = NUM_MODES + 1;
 
-	switch (decoder) {
-	case -1: // mode without multiple decoders
+	if (decoder == -1) // mode without multiple decoders
 		decoder = active_modem->get_mode();
-		if (last_mode > NUM_MODES)
-			last_mode = decoder;
-		else if (last_mode != decoder) {
-			buffers.clear();
-			last_mode = decoder;
-		}
-		break;
-	default:
-		if (last_mode > NUM_MODES)
-			last_mode = active_modem->get_mode();
-		else if (last_mode != active_modem->get_mode()) {
-			buffers.clear();
-			last_mode = active_modem->get_mode();
-		}
-		break;
+	if (last_mode != active_modem->get_mode()) {
+		buffers.clear();
+		last_mode = active_modem->get_mode();
 	}
 	if (afreq == 0)
 		afreq = active_modem->get_freq();
 
 	string& buf = buffers[decoder];
-	buf.reserve(DECBUFSIZE);
+	if (unlikely(buf.capacity() < DECBUFSIZE))
+		buf.reserve(DECBUFSIZE);
 
 	buf += c;
 	string::size_type n = buf.length();
@@ -90,13 +89,16 @@ void spot_recv(char c, int decoder, int afreq)
 		buf.erase(0, DECBUFSIZE - SEARCHLEN);
 	const char* search = buf.c_str() + (n > SEARCHLEN ? n - SEARCHLEN : 0);
 
-	for (cblist_t::iterator i = cblist.begin(); i != cblist.end(); ++i) {
-		if (i->rcb && unlikely(i->re->match(search))) {
-			const vector<regmatch_t>& m = i->re->suboff();
-			if (m.empty())
-				i->rcb(afreq, search, NULL, 0, i->data);
-			else
-				i->rcb(afreq, search, &m[0], m.size(), i->data);
+	for (rcblist_t::iterator i = rcblist.begin(); i != rcblist.end(); ++i) {
+		if (unlikely(i->first->match(search))) {
+			const vector<regmatch_t>& m = i->first->suboff();
+			for (list<callback_t*>::iterator j = i->second.begin();
+			     j != i->second.end() && (*j)->rcb; ++j) {
+				if (m.empty())
+					(*j)->rcb(last_mode, afreq, search, NULL, 0, (*j)->data);
+				else
+					(*j)->rcb(last_mode, afreq, search, &m[0], m.size(), (*j)->data);
+			}
 		}
 	}
 }
@@ -140,7 +142,7 @@ void spot_manual(const char* callsign, const char* locator, long long freq, trx_
 //
 void spot_register_log(spot_log_cb_t lcb, void* ldata)
 {
-	callback_t c = { ldata, lcb, 0, 0, 0 };
+	callback_t c = { ldata, lcb, 0, 0 };
 	cblist.push_back(c);
 }
 //
@@ -149,7 +151,7 @@ void spot_register_log(spot_log_cb_t lcb, void* ldata)
 //
 void spot_register_manual(spot_log_cb_t mcb, void* mdata)
 {
-	callback_t c = { mdata, 0, mcb, 0, 0 };
+	callback_t c = { mdata, 0, mcb, 0 };
 	cblist.push_back(c);
 }
 
@@ -164,41 +166,68 @@ void spot_register_manual(spot_log_cb_t mcb, void* mdata)
 //
 void spot_register_recv(spot_recv_cb_t rcb, void* rdata, const char* re, int reflags)
 {
-	callback_t c = { rdata, 0, 0, rcb, new fre_t(re, reflags) };
+	callback_t c = { rdata, 0, 0, rcb };
 	cblist.push_back(c);
+
+	fre_t* fre = new fre_t(re, reflags);
+	rcblist_t::iterator i = rcblist.find(fre);
+	if (i != rcblist.end()) {
+		i->second.push_back(&cblist.back());
+		delete fre;
+	}
+	else
+		rcblist[fre].push_back(&cblist.back());
 	show_spot(true);
 }
 
-void spot_unregister_log(spot_log_cb_t lcb, void* ldata)
+void spot_unregister_log(spot_log_cb_t lcb, const void* ldata)
 {
-	for (cblist_t::reverse_iterator ri = cblist.rbegin(); ri != cblist.rend(); ++ri) {
-		if (lcb == ri->lcb && ldata == ri->data) {
-			cblist.erase((++ri).base());
+	for (cblist_t::iterator i = cblist.begin(); i != cblist.end(); ++i) {
+		if (lcb == i->lcb && ldata == i->data) {
+			cblist.erase(i);
 			break;
 		}
 	}
 }
-void spot_unregister_manual(spot_log_cb_t mcb, void* mdata)
+void spot_unregister_manual(spot_log_cb_t mcb, const void* mdata)
 {
-	for (cblist_t::reverse_iterator ri = cblist.rbegin(); ri != cblist.rend(); ++ri) {
-		if (mcb == ri->mcb && mdata == ri->data) {
-			cblist.erase((++ri).base());
+	for (cblist_t::iterator i = cblist.begin(); i != cblist.end(); ++i) {
+		if (mcb == i->mcb && mdata == i->data) {
+			cblist.erase(i);
 			break;
 		}
 	}
 }
-void spot_unregister_recv(spot_recv_cb_t rcb, void* rdata)
+void spot_unregister_recv(spot_recv_cb_t rcb, const void* rdata)
 {
-	cblist_t::reverse_iterator ri;
-	for (ri = cblist.rbegin(); ri != cblist.rend(); ++ri) {
-		if (rcb == ri->rcb && rdata == ri->data) {
-			delete ri->re;
-			cblist.erase((++ri).base());
+	cblist_t::iterator i;
+	callback_t* p = 0;
+	for (i = cblist.begin(); i != cblist.end(); ++i) {
+		if (rcb == i->rcb && rdata == i->data) {
+			p = &*i;
+			cblist.erase(i);
 			break;
 		}
 	}
+	if (!p)
+		return;
+
+	// remove pointer from rcblist
+	for (rcblist_t::iterator j = rcblist.begin(); j != rcblist.end(); ++j) {
+		for (list<callback_t*>::iterator k = j->second.begin(); k != j->second.end(); ++k) {
+			if (*k == p) {
+				j->second.erase(k);
+				if (j->second.empty()) {
+					delete j->first;
+					rcblist.erase(j);
+				}
+				goto out;
+			}
+		}
+	}
 
-	for (ri = cblist.rbegin(); ri != cblist.rend(); ++ri)
-		if (ri->rcb) break;
-	show_spot(ri != cblist.rend());
+out:
+	for (i = cblist.begin(); i != cblist.end(); ++i)
+		if (i->rcb) break;
+	show_spot(i != cblist.end());
 }
