@@ -33,8 +33,21 @@
 #include <algorithm>
 #include <map>
 
+#include <FL/Fl.H>
+#include <FL/fl_draw.H>
+#include <FL/Fl_Widget.H>
+#include <FL/Fl_Repeat_Button.H>
+#include <FL/Fl_Light_Button.H>
+#include <FL/Fl_Menu_Button.H>
+#include <FL/Fl_Group.H>
+#include <FL/Fl_Box.H>
+#include <FL/Fl_Counter.H>
+#include <FL/Enumerations.H>
+
+#include "fl_digi.h"
+#include "trx.h"
+#include "misc.h"
 #include "waterfall.h"
-#include "threads.h"
 #include "main.h"
 #include "modem.h"
 #include "qrunner.h"
@@ -47,12 +60,15 @@
 
 #include "fldigi-config.h"
 #include "configuration.h"
+#include "status.h"
 #include "Viewer.h"
 #include "macros.h"
 #include "arq_io.h"
 #include "confdialog.h"
 #include "gettext.h"
 
+using namespace std;
+
 #define bwFFT		30
 #define cwRef		50
 #define bwX1		25
@@ -353,6 +369,18 @@ double WFdisp::powerDensity(double f0, double bw)
 	return pwrdensity/(bw+1);
 }
 
+void WFdisp::setPrefilter(int v)
+{
+	switch (v) {
+	case WF_FFT_RECTANGULAR: RectWindow(fftwindow, FFT_LEN*2); break;
+	case WF_FFT_BLACKMAN: BlackmanWindow(fftwindow, FFT_LEN*2); break;
+	case WF_FFT_HAMMING: HammingWindow(fftwindow, FFT_LEN*2); break;
+	case WF_FFT_HANNING: HanningWindow(fftwindow, FFT_LEN*2); break;
+	case WF_FFT_TRIANGULAR: TriangularWindow(fftwindow, FFT_LEN*2); break;
+	}
+	prefilter = v;
+}
+
 int WFdisp::log2disp(int v)
 {
 	double val = 255.0 * (reflevel- v) / ampspan;
@@ -1001,7 +1029,6 @@ void xmtrcv_cb(Fl_Widget *w, void *vi)
 		active_modem->set_stopflag(false);
 		trx_transmit();
 	} else {
-		extern Fl_Button* btnTune;
 		if (btnTune->value()) {
 			btnTune->value(0);
 			btnTune->do_callback();
@@ -1011,8 +1038,8 @@ void xmtrcv_cb(Fl_Widget *w, void *vi)
 			TransmitText->clear();
 			if (arq_text_available)
 				AbortARQ();
-			if (progdefaults.useTimer)
-				progdefaults.useTimer = false;
+			if (progStatus.timer)
+				progStatus.timer = 0;
 		}
 	}
 	restoreFocus();
@@ -1461,43 +1488,6 @@ static void hide_cursor(void *w)
 		reinterpret_cast<Fl_Widget *>(w)->window()->cursor(cursor = FL_CURSOR_NONE);
 }
 
-map<string, qrg_mode_t> qsy_map;
-static qrg_mode_t last;
-
-void note_qrg(bool check, char prefix, char suffix)
-{
-	qrg_mode_t m;
-	m.rfcarrier = wf->rfcarrier();
-	m.carrier = active_modem->get_freq();
-	m.mode = active_modem->get_mode();
-	if (check && last == m)
-		return;
-	last = m;
-
-	char buf[64];
-
-	time_t t = time(NULL);
-	struct tm tm;
-	gmtime_r(&t, &tm);
-	size_t r1;
-	if ((r1 = strftime(buf, sizeof(buf), "<<%FT%H:%MZ ", &tm)) == 0)
-		return;
-
-	size_t r2;
-	if (m.rfcarrier)
-		r2 = snprintf(buf+r1, sizeof(buf)-r1, "%s @ %lld%c%04d>>",
-			     mode_info[m.mode].name, m.rfcarrier, (wf->USB() ? '+' : '-'), m.carrier);
-	else
-		r2 = snprintf(buf+r1, sizeof(buf)-r1, "%s @ %04d>>", mode_info[m.mode].name, m.carrier);
-	if (r2 >= sizeof(buf)-r1)
-		return;
-
-	qsy_map[buf] = m;
-	ReceiveText->add(prefix);
-	ReceiveText->add(buf, FTextBase::QSY);
-	ReceiveText->add(suffix);
-}
-
 static void insert_text(bool check = false)
 {
 	if (check) {
@@ -1505,10 +1495,11 @@ static void insert_text(bool check = false)
 		m.rfcarrier = wf->rfcarrier();
 		m.carrier = active_modem->get_freq();
 		m.mode = active_modem->get_mode();
-		if (last.mode == m.mode && last.rfcarrier == m.rfcarrier &&
-		    abs(last.carrier - m.carrier) <= 16)
+		extern qrg_mode_t last_marked_qrg;
+		if (last_marked_qrg.mode == m.mode && last_marked_qrg.rfcarrier == m.rfcarrier &&
+		    abs(last_marked_qrg.carrier - m.carrier) <= 16)
 			return;
-		last = m;
+		last_marked_qrg = m;
 	}
 
 	string::size_type i;
@@ -1528,11 +1519,12 @@ static void find_signal_text(void)
 	int freq = active_modem->get_freq();
 	trx_mode mode = active_modem->get_mode();
 
+	extern map<string, qrg_mode_t> qrg_marks;
 	map<string, qrg_mode_t>::const_iterator i;
-	for (i = qsy_map.begin(); i != qsy_map.end(); ++i)
+	for (i = qrg_marks.begin(); i != qrg_marks.end(); ++i)
 		if (i->second.mode == mode && abs(i->second.carrier - freq) <= 20)
 			break;
-	if (i != qsy_map.end()) {
+	if (i != qrg_marks.end()) {
 		// Search backward from the current text cursor position, then
 		// try the other direction
 		int pos = ReceiveText->insert_position();
@@ -1636,8 +1628,8 @@ int WFdisp::handle(int event)
 			if (Fl::event_state() & FL_CTRL)
 				viewer_paste_freq(cursorFreq(xpos));
 			else {
-				btn_afconoff->value(!btn_afconoff->value());
-				btn_afconoff->do_callback();
+				btnAFC->value(!btnAFC->value());
+				btnAFC->do_callback();
 			}
 		}
 		break;
@@ -1656,7 +1648,7 @@ int WFdisp::handle(int event)
 				break;
 			if (!(Fl::event_state() & (FL_CTRL | FL_META | FL_ALT | FL_SHIFT))) {
 				if (Fl::event_clicks() == 1)
-					note_qrg(true, '\n', '\n');
+					note_qrg(true, "\n", "\n");
 				else
 					if (progdefaults.WaterfallClickInsert)
 						insert_text(true);
