@@ -25,20 +25,29 @@
 
 #include <config.h>
 
+#ifdef __MINGW32__
+#  include "compat.h"
+#endif
+
+#include <string>
+#include <sstream>
+#include <cmath>
+#include <cstdlib>
+#include <cstdio>
+#include <cstring>
+
 #include <time.h>
 #include <sys/stat.h>
 #include <sys/types.h>
 
-#include <FL/fl_ask.H>
+#include <FL/Fl.H>
+#include <FL/fl_draw.H>
 
-#if USE_LIBJPEG
-#  include <cstdio>
-#  include <jpeglib.h>
-#endif
-#if USE_LIBPNG
-#  include <png.h>
-#endif
+#include <png.h>
 
+#include "fl_digi.h"
+#include "trx.h"
+#include "fl_lock.h"
 #include "picture.h"
 #include "debug.h"
 
@@ -50,7 +59,6 @@ picture::picture (int X, int Y, int W, int H) :
 	width = W;
 	height = H;
 	depth = 3;
-	quality = 80; // for jpeg export
 	bufsize = W * H * depth;
 	numcol = 0;
 	slantdir = 0;
@@ -241,7 +249,7 @@ static FILE* open_file(const char* name, const char* suffix)
 		(void)gmtime_r(&time_sec, &ztime);
 
 		size_t sz;
-		if ((sz = strftime(newfn + flen, newlen - flen, "pic_%F_%H%M%Sz", &ztime)) > 0) {
+		if ((sz = strftime(newfn + flen, newlen - flen, "pic_%Y-%m-%d_%H%M%Sz", &ztime)) > 0) {
 			strncpy(newfn + flen + sz, suffix, newlen - flen - sz);
 			newfn[newlen - 1] = '\0';
 			mkdir(name, 0777);
@@ -257,53 +265,6 @@ static FILE* open_file(const char* name, const char* suffix)
 	return fp;
 }
 
-#if USE_LIBJPEG
-//
-// save_jpeg - Write a captured picture to a JPEG format file.
-//
-
-int picture::save_jpeg(const char *filename)
-{
-	unsigned char		*ptr;		// Pointer to image data
-	FILE				*fp = 0;	// File pointer
-	struct jpeg_compress_struct	info;		// Compressor info
-	struct jpeg_error_mgr		err;		// Error handler info
-
-	if ((fp = open_file(filename, ".jpg")) == NULL)
-		return -1;
-
-// Setup the JPEG compression stuff...
-	info.err = jpeg_std_error(&err);
-	jpeg_create_compress(&info);
-	jpeg_stdio_dest(&info, fp);
-
-	info.image_width      = width;
-	info.image_height     = height;
-	info.input_components = depth;
-	info.in_color_space   = JCS_RGB;//simg->d() == 1 ? JCS_GRAYSCALE : JCS_RGB;
-
-	jpeg_set_defaults(&info);
-	jpeg_set_quality(&info, quality, 1);
-	jpeg_simple_progression(&info);
-
-	info.optimize_coding = 1;
-
-// Save the image...
-	jpeg_start_compress(&info, 1);
-	while (info.next_scanline < info.image_height) {
-		ptr = &vidbuf[info.next_scanline * width * depth];
-		jpeg_write_scanlines(&info, &ptr, 1);
-	}
-	jpeg_finish_compress(&info);
-	jpeg_destroy_compress(&info);
-
-	fclose(fp);
-
-	return 0;
-}
-#endif // USE_LIBJPEG
-
-#if USE_LIBPNG
 int picture::save_png(const char* filename)
 {
 	FILE* fp;
@@ -336,10 +297,26 @@ int picture::save_png(const char* filename)
 		     PNG_COLOR_TYPE_RGB, PNG_INTERLACE_NONE,
 		     PNG_COMPRESSION_TYPE_DEFAULT, PNG_FILTER_TYPE_DEFAULT);
 
-	// TODO: write more useful image comments
+	// write text comments
+	struct tm tm;
+	time_t t = time(NULL);
+	gmtime_r(&t, &tm);
+	char z[20 + 1];
+	strftime(z, sizeof(z), "%Y-%m-%dT%H:%M:%SZ", &tm);
+	z[sizeof(z) - 1] = '\0';
+
+	ostringstream comment;
+	comment << "Program: " PACKAGE_STRING << '\n'
+		<< "Received: " << z << '\n'
+		<< "Modem: " << mode_info[active_modem->get_mode()].name << '\n'
+		<< "Frequency: " << inpFreq->value() << '\n';
+	if (inpCall->size())
+		comment << "Log call: " << inpCall->value() << '\n';
+
+	// set text
 	png_text text;
 	text.key = strdup("Comment");
-	text.text = strdup("MFSK-16 image decoded by " PACKAGE_STRING);
+	text.text = strdup(comment.str().c_str());
 	text.compression = PNG_TEXT_COMPRESSION_NONE;
 	png_set_text(png, info, &text, 1);
 
@@ -362,7 +339,6 @@ int picture::save_png(const char* filename)
 
 	return 0;
 }
-#endif // USE_LIBPNG
 
 
 int picbox::handle(int event)
@@ -381,18 +357,18 @@ int picbox::handle(int event)
 	}
 
 	// handle FL_PASTE
-	const char* text = Fl::event_text();
-	if (strstr(text, "file://"))
-		text += strlen("file://");
-	char* p;
-	if ((p = strchr(text, '\r')))
-		*p = '\0';
+	string text = Fl::event_text();
+	string::size_type p;
+	if ((p = text.find("file://")) != string::npos)
+		text.erase(0, p + strlen("file://"));
+	if ((p = text.find('\r')) != string::npos)
+		text.erase(p);
 
 	struct stat st;
-	if (stat(text, &st) == -1 || !S_ISREG(st.st_mode))
+	if (stat(text.c_str(), &st) == -1 || !S_ISREG(st.st_mode))
 		return 0;
 	extern void load_image(const char*);
-	load_image(text);
+	load_image(text.c_str());
 
 	return 1;
 }
